@@ -25,6 +25,7 @@
 #include <QPainter>
 #include <QCheckBox>
 #include <QLabel>
+#include <QProgressBar>
 
 #include "QvkAudioController.h"
 #include "QvkPulseAudioWatcher.h"
@@ -32,9 +33,11 @@
 #include "QvkPulseAudioDevices.h"
 #include "global.h"
 
-QvkAudioController::QvkAudioController( Ui_formMainWindow *ui_mainwindow )
+QvkAudioController::QvkAudioController(Ui_formMainWindow *ui_mainwindow )
 {
     ui = ui_mainwindow;
+    ui->verticalLayoutAudioDevices->setAlignment( Qt::AlignLeft | Qt::AlignTop );
+    global::listChildren = new QList<QLineEdit*>();
 }
 
 
@@ -50,6 +53,9 @@ void QvkAudioController::init()
     getAllDevices();
 }
 
+// systemctl --user stop pipewire.socket
+// systemctl --user start pipewire.socket
+
 
 void QvkAudioController::getAllDevices()
 {
@@ -58,20 +64,46 @@ void QvkAudioController::getAllDevices()
         list << QvkPulseAudioDevices::getAllDevices();
         if ( !list.empty() ) {
             for ( int i = 0; i < list.count(); i++ ) {
-                QCheckBox *checkboxAudioDevice = new QCheckBox();
-                connect( checkboxAudioDevice, SIGNAL( clicked( bool ) ), this, SLOT( slot_audioDeviceSelected() ) );
-                checkboxAudioDevice->setText( QString( list.at(i) ).section( ":::", 1, 1 ) );
-                checkboxAudioDevice->setAccessibleName( QString( list.at(i) ).section( ":::", 0, 0 ) );
-                checkboxAudioDevice->setObjectName( "checkboxAudioDevice-" + QString::number( i ) );
-                checkboxAudioDevice->setToolTip( tr ( "Select one or more devices" ) );
-                ui->verticalLayoutAudioDevices->addWidget( checkboxAudioDevice );
-                qDebug().noquote() << global::nameOutput << "[Audio] Found:" << QString( list.at(i) ).section( ":::", 1, 1 ) << "Device:" << QString( list.at(i) ).section( ":::", 0, 0 );
+                QString name = list.at(i).section( ":::", 1, 1 );
+                QString device = list.at(i).section( ":::", 0, 0 );
+
+                // Führende Null voranstellen
+                QString index;
+                if ( i < 10 ) {
+                    index = "0" + QString::number(i);
+                } else {
+                    index = QString::number(i);
+                }
+
+                QHBoxLayout *hBoxLayout = new QHBoxLayout; // Für Checkbox und Progressbar
+                hBoxLayout->setSpacing(0);
+                hBoxLayout->setObjectName( "vBoxLayoutAudioDevice-" + index );
+                QCheckBox *checkBox = new QCheckBox();
+                connect( checkBox, SIGNAL( clicked( bool ) ), this, SLOT( slot_audioDeviceSelected() ) );
+                checkBox->setAccessibleName( device );
+                checkBox->setObjectName( "checkboxAudioDevice-" + index );
+                checkBox->setToolTip( tr ( "Select one or more devices" ) );
+
+                if ( QString( list.at(i) ).section( ":::", 0, 0 ).contains( "monitor" ) ) {
+                    checkBox->setIconSize( QSize( 15, 15 ) );
+                    checkBox->setIcon( QIcon( ":/pictures/screencast/speaker.png" ) );
+                } else {
+                    checkBox->setIconSize( QSize( 16, 16 ) );
+                    checkBox->setIcon( QIcon( ":/pictures/screencast/microphone.png" ) );
+                }
+
+                hBoxLayout->addWidget( checkBox );
+                ui->verticalLayoutAudioDevices->addLayout( hBoxLayout );
+
+                qDebug().noquote() << global::nameOutput << "[Audio] Found:" << name << "Device:" << device;
+
+                vkLevelMeterController = new QvkLevelMeterController;
+                vkLevelMeterController->add_ProgressBar( checkBox, hBoxLayout, name );
+                vkLevelMeterController->set_Text( name );
+
             }
             qDebug().noquote();
 
-            QSpacerItem *verticalSpacerAudioDevices = new QSpacerItem( 20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding );
-            ui->verticalLayoutAudioDevices->addSpacerItem( verticalSpacerAudioDevices );
-
             QvkPulseAudioWatcher *vkPulseAudioWatcher = new QvkPulseAudioWatcher( ui );
             vkPulseAudioWatcher->start_monitor();
         } else {
@@ -88,6 +120,7 @@ void QvkAudioController::getAllDevices()
 
             QvkPulseAudioWatcher *vkPulseAudioWatcher = new QvkPulseAudioWatcher( ui );
             vkPulseAudioWatcher->start_monitor();
+            ui->verticalLayoutAudioDevices->setAlignment( Qt::AlignLeft | Qt::AlignTop );
         }
     } else {
         QLabel *label = new QLabel();
@@ -110,51 +143,15 @@ void QvkAudioController::getAllDevices()
 
 
 void QvkAudioController::slot_audioDeviceSelected()
-{
-    audioIconOnOff( isAudioDeviceSelected() );
-}
-
-
-bool QvkAudioController::isAudioDeviceSelected()
 {
     bool value = false;
     QList<QCheckBox *> listCheckBox = ui->scrollAreaAudioDevice->findChildren<QCheckBox *>();
     for ( int i = 0; i < listCheckBox.count(); i++ ) {
-        if ( listCheckBox.at(i)->checkState() == Qt::Checked ) {
+        QCheckBox *checkBox = listCheckBox.at(i);
+        if ( checkBox->checkState() == Qt::Checked ) {
             value = true;
             break;
         }
     }
-    return value;
+    emit signal_haveAudioDeviceSelected( value );
 }
-
-
-/*
- * Set a new icon with a red cross
- */
-void QvkAudioController::audioIconOnOff( bool state )
-{
-    QIcon myIcon( ":/pictures/screencast/microphone.png" );
-    if ( state == false  ) {
-        QSize size = ui->tabWidgetScreencast->iconSize();
-        QPixmap workPixmap( myIcon.pixmap( size ) );
-        QPainter painter;
-        QPen pen;
-        painter.begin( &workPixmap );
-        pen.setColor( QString( "#3daee9" ) );
-        pen.setWidth( 2 );
-        painter.setPen( pen );
-        painter.drawLine ( 5, 5, size.width()-5, size.height()-5 );
-        painter.drawLine ( 5, size.height()-5, size.width()-5, 5 );
-        painter.end();
-        int index = ui->tabWidgetScreencast->indexOf( ui->tabAudio );
-        ui->tabWidgetScreencast->setTabIcon( index, workPixmap );
-        emit signal_haveAudioDeviceSelected( false );
-
-    } else {
-        int index = ui->tabWidgetScreencast->indexOf( ui->tabAudio );
-        ui->tabWidgetScreencast->setTabIcon( index, myIcon );
-        emit signal_haveAudioDeviceSelected( true );
-    }
-}
-
