@@ -27,15 +27,17 @@
 
 #include "ui_formMainWindow.h"
 
+#include "QvkLevelMeterController.h"
+
 class QvkAudioController: public QObject
 {
     Q_OBJECT
 
 public:
-    QvkAudioController( Ui_formMainWindow *ui_mainwindow );
+    QvkAudioController(Ui_formMainWindow *ui_mainwindow );
     virtual ~QvkAudioController();
     void init();
-
+    QvkLevelMeterController *vkLevelMeterController;
 
 public slots:
 
@@ -43,8 +45,6 @@ public slots:
 private:
     Ui_formMainWindow *ui;
     void getAllDevices();
-    bool isAudioDeviceSelected();
-    void audioIconOnOff( bool state );
 
 
 private slots:
