@@ -35,7 +35,7 @@ class QvkPulseAudioWatcher: public QObject
 
 
 public:
-    QvkPulseAudioWatcher( Ui_formMainWindow *ui_mainwindow );
+    QvkPulseAudioWatcher(Ui_formMainWindow *ui_mainwindow );
     virtual ~QvkPulseAudioWatcher();
     void start_monitor();
 
@@ -45,8 +45,6 @@ public slots:
 private:
     Ui_formMainWindow *ui;
     QTimer *timer;
-    bool isAudioDeviceSelected();
-    void audioIconOnOff(bool state);
 
 
 private slots:
