@@ -60,7 +60,7 @@ void QvkCountdown::createCountdownWindow()
     vkCountdownWindow = new QvkCountdownWindow( this );
     vkCountdownWindow->setWindowFlags( Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint | Qt::ToolTip ); //With tooltip, no entry in Taskbar
 
-    connect( vkCountdownWindow, SIGNAL( signal_countDownCancel( bool ) ), this, SLOT( slot_cancel( bool ) ) );
+    connect( vkCountdownWindow, SIGNAL( signal_countDownCancel(bool) ), this, SLOT( slot_cancel(bool) ) );
 
     x = 0;
     y = 0;
@@ -92,8 +92,7 @@ void QvkCountdown::slot_updateTimer()
     vkCountdownWindow->gradValue = 0;
     vkCountdownWindow->countValue--;
 
-    if ( vkCountdownWindow->countValue == 0 )
-    {
+    if ( vkCountdownWindow->countValue == 0 ) {
         vkCountdownWindow->setGeometry( x, y, 1, 1 );
         vkCountdownWindow->hide();
         timer->stop();
