@@ -26,17 +26,13 @@
 
 namespace global
 {
+    QString version = "4.4.0";
     QString name = "vokoscreenNG";
     QString nameOutput = "[" + name + "]";
     int showclickCounter = 0;
-    QLineEdit *lineEdit_EOS;
-    bool testWASAPI = false;
-
-#ifdef Q_OS_LINUX
-    QString version = "3.8.0";
-#endif
-
-#ifdef Q_OS_WIN
-    QString version = "3.8.0";
-#endif
+    QLineEdit *lineEditWASAPIWatcher;
+    QList<QLineEdit*> *listChildren;
+    QLineEdit *lineEditConvertMP4;
+    QLineEdit *lineEditConvertGIF;
+    QLineEdit *lineEditConvertRepair;
 }
