@@ -29,6 +29,9 @@ namespace global
     extern QString nameOutput;
     extern QString version;
     extern int showclickCounter;
-    extern QLineEdit *lineEdit_EOS;
-    extern bool testWASAPI;
+    extern QLineEdit *lineEditWASAPIWatcher;
+    extern QList<QLineEdit*> *listChildren;
+    extern QLineEdit *lineEditConvertMP4;
+    extern QLineEdit *lineEditConvertGIF;
+    extern QLineEdit *lineEditConvertRepair;
 }
