@@ -60,7 +60,6 @@ void QvkHalo::createHaloPreviewWidget()
 void QvkHalo::createHaloWindow()
 {
     vkHaloWindow = new QvkHaloWindow( this );
-    vkHaloWindow->setWindowFlags( Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint | Qt::ToolTip ); //With tooltip, no entry in Taskbar
 }
 
 
@@ -70,13 +69,13 @@ void QvkHalo::createSpezialSlider()
     ui->horizontalLayoutHaloHole->insertWidget( 0, vkSpezialSliderHole );
     vkSpezialSliderHole->setObjectName( "sliderhaloHole" );
     vkSpezialSliderHole->setTracking( true );
-    vkSpezialSliderHole->setMinimum( 20 );
+    vkSpezialSliderHole->setMinimum( 5 );
     vkSpezialSliderHole->setMaximum( 40 );
-    vkSpezialSliderHole->setValue( 30 ); // This value must be greater than the holeDefault in order to be changed after the connect
+    vkSpezialSliderHole->setValue( holeDefault + 1 ); // This value must be greater than the holeDefault in order to be changed after the connect
     vkSpezialSliderHole->setShowValue( false );
     vkSpezialSliderHole->setBigHandel( false );
     vkSpezialSliderHole->show();
-    connect( vkSpezialSliderHole, SIGNAL( valueChanged( int ) ), this, SLOT( slot_valueChanged_SpezialSlider_Hole( int ) ) );
+    connect( vkSpezialSliderHole, SIGNAL( valueChanged(int) ), this, SLOT( slot_valueChanged_SpezialSlider_Hole(int) ) );
     vkSpezialSliderHole->setValue( holeDefault );
 
     vkSpezialSliderDiameter = new QvkSpezialSlider( Qt::Horizontal );
@@ -89,7 +88,7 @@ void QvkHalo::createSpezialSlider()
     vkSpezialSliderDiameter->setShowValue( false );
     vkSpezialSliderDiameter->setBigHandel( false );
     vkSpezialSliderDiameter->show();
-    connect( vkSpezialSliderDiameter, SIGNAL( valueChanged( int ) ), this, SLOT( slot_valueChanged_SpezialSlider_Diameter( int ) ) );
+    connect( vkSpezialSliderDiameter, SIGNAL( valueChanged(int) ), this, SLOT( slot_valueChanged_SpezialSlider_Diameter(int) ) );
     vkSpezialSliderDiameter->setValue( diameterDefault );
 
     vkSpezialSliderOpacity = new QvkSpezialSlider( Qt::Horizontal );
@@ -102,7 +101,7 @@ void QvkHalo::createSpezialSlider()
     vkSpezialSliderOpacity->setShowValue( false );
     vkSpezialSliderOpacity->setBigHandel( false );
     vkSpezialSliderOpacity->show();
-    connect( vkSpezialSliderOpacity, SIGNAL( valueChanged( int ) ), this, SLOT( slot_valueChanged_SpezialSlider_Opacity( int ) ) );
+    connect( vkSpezialSliderOpacity, SIGNAL( valueChanged(int) ), this, SLOT( slot_valueChanged_SpezialSlider_Opacity(int) ) );
     vkSpezialSliderOpacity->setValue( opacityDefault );
 }
 
@@ -137,16 +136,15 @@ void QvkHalo::slot_valueChanged_SpezialSlider_Opacity( int value )
 void QvkHalo::createColorButtons()
 {
     QList<QHBoxLayout *> listLayaout = ui->gridLayout_halo_color_pushButton->findChildren<QHBoxLayout *>();
-    for ( int i = 0; i < listLayaout.count(); i++ )
-    {
-        for ( int x = 0; x < 20; x++ )
-        {
-            if ( listLayaout.at(i)->objectName().section( "_", 2, 2 ) == QVariant::fromValue( Qt::GlobalColor(x) ).toString() )
-            {
+    for ( int i = 0; i < listLayaout.count(); i++ ) {
+        for ( int x = 0; x < 20; x++ ) {
+            QHBoxLayout *boxLayout = listLayaout.at(i);
+            QVariant variant = QVariant::fromValue( Qt::GlobalColor(x) );
+            if ( boxLayout->objectName().section( "_", 2, 2 ) == variant.toString() ) {
                 QvkPushButton *vkPushButton = new QvkPushButton( Qt::GlobalColor(x) );
-                vkPushButton->setObjectName( "PushButton_Halo_color_" + QVariant::fromValue( Qt::GlobalColor(x) ).toString() );
+                vkPushButton->setObjectName( "PushButton_Halo_color_" + variant.toString() );
                 vkPushButton->setMaximumHeight( 23 );
-                listLayaout.at(i)->addWidget( vkPushButton );
+                boxLayout->addWidget( vkPushButton );
                 connect( vkPushButton, &QPushButton::clicked, this, [=]() { vkHaloPreviewWidget->setColor( Qt::GlobalColor(x) );
                                                                             vkHaloWindow->setColor( Qt::GlobalColor(x) );
                                                                            } );
@@ -161,21 +159,24 @@ void QvkHalo::createSpezialCheckBox()
 {
     vkSpezialCheckbox = new QvkSpezialCheckbox();
     vkSpezialCheckbox->setObjectName( "spezialCheckboxHalo" );
+    vkSpezialCheckbox->set_colorChecked( Qt::darkGreen );
+    vkSpezialCheckbox->set_colorUnChecked( Qt::darkRed );
+    vkSpezialCheckbox->set_imageChecked( ":/pictures/spezialCheckBox/on.png" );
+    vkSpezialCheckbox->set_imageUnChecked( ":/pictures/spezialCheckBox/off.png" );
+    vkSpezialCheckbox->set_waitBeforeTrigger( 0 );
     ui->horizontalLayout_48->insertWidget( 1, vkSpezialCheckbox );
-    connect( vkSpezialCheckbox, SIGNAL( signal_clicked( bool ) ), this, SLOT( slot_haloOnOff( bool ) ) );
+    connect( vkSpezialCheckbox, SIGNAL( signal_clicked(bool) ), this, SLOT( slot_haloOnOff(bool) ) );
 }
 
 
 void QvkHalo::slot_haloOnOff( bool value )
 {
-    if ( value == true )
-    {
+    if ( value == true ) {
         timerID = startTimer( 10, Qt::PreciseTimer );
         vkHaloWindow->show();
     }
 
-    if ( value == false )
-    {
+    if ( value == false ) {
         killTimer( timerID );
         vkHaloWindow->hide();
     }
@@ -189,12 +190,17 @@ void QvkHalo::timerEvent( QTimerEvent *event )
 {
     Q_UNUSED(event);
 
-    if ( global::showclickCounter == 0 )
-    {
+    if ( global::showclickCounter == 0 ) {
         vkHaloWindow->raise();
     }
 
     vkHaloWindow->move( QCursor::pos().x() - vkHaloWindow->diameter/2, QCursor::pos().y() - vkHaloWindow->diameter/2 );
+
+    if ( screenOld != vkHaloWindow->screen() ) {
+        screenOld = vkHaloWindow->screen();
+        vkHaloWindow->resize( 100, 100 );
+        vkHaloWindow->repaint();
+    }
 }
 
 
@@ -206,5 +212,4 @@ void QvkHalo::setToolButtonDefaultValues()
     connect( ui->toolButtonHaloDiameterDefault, &QToolButton::clicked, this, [=]() { vkSpezialSliderDiameter->setValue( diameterDefault ); } );
     connect( ui->toolButtonHaloOpacityDefault,  &QToolButton::clicked, this, [=]() { vkSpezialSliderOpacity->setValue( opacityDefault ); } );
     connect( ui->toolButtonHaloHoleDefault,     &QToolButton::clicked, this, [=]() { vkSpezialSliderHole->setValue( holeDefault); } );
-
 }
