@@ -26,14 +26,28 @@
 #include <QDebug>
 #include <QBitmap>
 
+
+#ifdef Q_OS_UNIX
+QvkHaloWindow::QvkHaloWindow( QWidget *parent )
+{
+    Q_UNUSED(parent)
+    setWindowFlags( Qt::X11BypassWindowManagerHint | Qt::WindowStaysOnTopHint );
+    setAttribute( Qt::WA_TranslucentBackground, true );
+    resize( 100, 100 );
+    setCursor( Qt::BlankCursor );
+}
+#endif
+
+#ifdef Q_OS_WIN
 QvkHaloWindow::QvkHaloWindow( QWidget *parent )
 {
     setParent( parent );
-    setCursor( Qt::BlankCursor );
+    setWindowFlags( Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint | Qt::ToolTip );
     setAttribute( Qt::WA_TranslucentBackground, true );
-    show();
+    resize( 100, 100 );
+    setCursor( Qt::BlankCursor );
 }
-
+#endif
 
 QvkHaloWindow::~QvkHaloWindow()
 {
@@ -44,13 +58,13 @@ void QvkHaloWindow::paintEvent( QPaintEvent *event )
 {
     Q_UNUSED(event);
 
-    QPixmap pixmap( 100 * devicePixelRatioF(), 100 * devicePixelRatioF() );
+    QPixmap pixmap( 100, 100 );
     pixmap.fill( Qt::transparent );
-    pixmap.setDevicePixelRatio( devicePixelRatioF() );
 
     QPainter painterPixmap;
     painterPixmap.begin( &pixmap );
-    painterPixmap.setRenderHints( QPainter::Antialiasing, true );
+    painterPixmap.setRenderHint( QPainter::Antialiasing, true );
+    painterPixmap.setRenderHint( QPainter::SmoothPixmapTransform, true );
 
     qreal penWidth = diameter/2 - holeRadius;
     QPen pen;
@@ -64,6 +78,8 @@ void QvkHaloWindow::paintEvent( QPaintEvent *event )
 
     QPainter painter;
     painter.begin( this );
+    painter.setRenderHint( QPainter::Antialiasing, true );
+    painter.setRenderHint( QPainter::SmoothPixmapTransform, true );
     painter.drawPixmap( QPointF( 0, 0 ), pixmap );
     painter.end();
 
