@@ -25,15 +25,23 @@
 
 #include <QScreen>
 #include <QGuiApplication>
+#include <QCoreApplication>
 #include <QDebug>
 #include <QStandardPaths>
 #include <QPushButton>
-#include <QTimer>
 #include <QThread>
 #include <QMessageBox>
 #include <QDesktopServices>
 #include <QBitmap>
 #include <QColor>
+#include <QToolButton>
+#include <QList>
+#include <QPixmap>
+#include <QMap>
+#include <QPainter>
+#include <QRectF>
+#include <QPen>
+#include <QPoint>
 
 QvkImageFromTabs::QvkImageFromTabs( QvkMainWindow *parent )
 {
@@ -63,7 +71,8 @@ void QvkImageFromTabs::slot_make_picture_from_tabs()
 
     QList<QToolButton *> listToolButton = myParent->ui->widgetSidbar->findChildren<QToolButton *>();
     for ( int i = 1; i < listToolButton.count(); i++ ) {
-        listToolButton.at(i)->click();
+        QToolButton *toolButton = listToolButton.at(i);
+        toolButton->click();
         for ( int y = 0; y < 30; y++ ) {
             QCoreApplication::processEvents();
             QThread::msleep( 20 );
@@ -71,7 +80,9 @@ void QvkImageFromTabs::slot_make_picture_from_tabs()
         slot_make_picture_from_tab();
     }
 
-    listToolButton.at(0)->click();
+
+    QToolButton *toolButton = listToolButton.at(0);
+    toolButton->click();
 
     if ( QDesktopServices::openUrl( QUrl( "file:///" + QStandardPaths::writableLocation( QStandardPaths::PicturesLocation ), QUrl::TolerantMode ) ) == false ) {
         QPixmap pixmap( ":/pictures/status/information.png" );
@@ -95,11 +106,13 @@ void QvkImageFromTabs::slot_make_picture_from_tab()
     int sumScreenWidth = 0;
     QMap<int, QString> map;
     for ( int i = 0; i < screenList.count(); i++ ) {
-        sumScreenWidth = sumScreenWidth + screenList.at(i)->size().width();
-        map.insert( screenList.at(i)->size().height(), QString::number( screenList.at(i)->size().height() ) );
+        QScreen *screen = screenList.at(i);
+        sumScreenWidth = sumScreenWidth + screen->size().width();
+        map.insert( screen->size().height(), QString::number( screen->size().height() ) );
     }
 
-    QPixmap pixmapScreen( screenList.at(0)->grabWindow( 0, 0, 0, sumScreenWidth, map.values().last().toInt() ) );
+    QScreen *screen = screenList.at(0);
+    QPixmap pixmapScreen = screen->grabWindow( 0, 0, 0, sumScreenWidth, map.values().last().toInt() );
 
     int left = myParent->windowHandle()->frameMargins().left();
     int top = myParent->windowHandle()->frameMargins().top();
@@ -127,6 +140,11 @@ void QvkImageFromTabs::slot_make_picture_from_tab()
     painter_1.setRenderHint( QPainter::Antialiasing, true );
     painter_1.setRenderHint( QPainter::SmoothPixmapTransform, true );
     painter_1.drawPixmap( 0, 0, windowPixmap );
+    QPen pen;
+    pen.setColor( Qt::gray );
+    pen.setWidth( 1 );
+    painter_1.setPen( pen );
+    painter_1.drawRoundedRect( rect, 8, 8, Qt::AbsoluteSize );
     painter_1.end();
 
     pixmapImage.setMask( pixmap.mask() );
