@@ -7,10 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>الكاميرا</translation>
+        <source>Select one or more devices</source>
+        <translation>اِختر جهازاً أو أكثر</translation>
     </message>
 </context>
 <context>
@@ -50,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation> أظهر النافذة</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>تغيير لملء الشاشة</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>الكاميرا</translation>
@@ -79,10 +71,10 @@
     </message>
 </context>
 <context>
-    <name>QvkDirectSoundController</name>
+    <name>QvkDirDialog</name>
     <message>
-        <source>Select one or more devices</source>
-        <translation>اِختر جهازاً أو أكثر</translation>
+        <source>Dialog</source>
+        <translation>الحوار</translation>
     </message>
 </context>
 <context>
@@ -103,6 +95,17 @@
         <translation>الرجاء تنصيب اداره الملفات</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>لايمكن ايجاد اداراه الملفات </translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>الرجاء تنصيب اداره الملفات</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -132,14 +135,6 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>شاشة كاملة</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>نافذة</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
@@ -166,6 +161,33 @@
         <translation>تبرع</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>الملف المصدري</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>صفحة البرنامج</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>الترجمات</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>تبرع</translation>
+    </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>لايمكن ايجاد اداراه الملفات </translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>الرجاء تنصيب اداره الملفات</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -173,6 +195,13 @@
         <translation>اِختر جهازاً أو أكثر</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>اِختر جهازاً أو أكثر</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -356,10 +385,6 @@
         <source>Audiocodec</source>
         <translation>ترميز الصوت</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>جوده</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>لا تسجل مؤشر الفأرة</translation>
@@ -464,18 +489,6 @@
         <source>Gray</source>
         <translation>رمادي</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+SHIFT+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+SHIFT+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+SHIFT+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>شغل اخر تسجيل</translation>
@@ -484,10 +497,6 @@
         <source>Open folder</source>
         <translation>افتح الدليل</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>CTRL+SHIFT+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation> تصغير البرنامج عند بدأ التسجيل </translation>
@@ -512,10 +521,6 @@
         <source>Remove window frame</source>
         <translation>إزالة إطار النافذة</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>تبرع</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>إعادة ضبط جميع الإعدادات في التشغيل القادم</translation>
@@ -592,6 +597,161 @@
         <source>Seconds wait before recording</source>
         <translation>ثواني الانتظار قبل بدء التسجيل</translation>
     </message>
+    <message>
+        <source>Window</source>
+        <translation>نافذة</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>شاشة كاملة</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>حقوق الطبع والنشر والترخيص من الصور</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>إنشاء صور لعلامات التبويب</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>معلومات الترخيص</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>تشغيل</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>إيقاف</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>مده التسجيل</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>حجم ملف الفيديو</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>مساحه التخزين المتاحه:</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>معلومه</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>نافذة</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>شاشة كاملة</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>منطقة</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>ترميز الفيديو</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>المشاهد</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>الصيغة</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>المتاح</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>غير متاح</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>اِبدأ</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>أوقِف</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>دليل</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>لا تسجل مؤشر الفأرة</translation>
+    </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>ترميز الصوت</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>مسار الفيديو</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>عدّ تنازلي</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>مساعده</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>عكس</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>رمادي</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>ابيض واسود</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>الكاميرا</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>تغيير الوجه الرأسي</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>تغيير الوجه الأفقي</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>إزالة إطار النافذة</translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation>الانتظار الثاني قبل التسجيل</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>أعاده للوضع </translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>إخفاء النافذة</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>ثواني الانتظار قبل بدء التسجيل</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -601,7 +761,7 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>شغّل</translation>
@@ -614,29 +774,5 @@
         <source>Stop</source>
         <translation>أوقِف</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>افتح الملف</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>شاشة كاملة</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>الإطار السابق</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>الإطار التالي</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>صامت</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>حرك قائمه الخيارات</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
