@@ -7,17 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>Càmera</translation>
-    </message>
-</context>
-<context>
-    <name>QvkCameraSettingsDialog</name>
-    <message>
-        <source>Camera settings</source>
-        <translation>Ajustaments de la càmera</translation>
+        <source>Select one or more devices</source>
+        <translation>Seleccioneu un o més dispositius</translation>
     </message>
 </context>
 <context>
@@ -57,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>Alterna a finestra</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>Alterna a pantalla completa</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>Càmera</translation>
@@ -92,13 +77,6 @@
         <translation>Diàleg</translation>
     </message>
 </context>
-<context>
-    <name>QvkDirectSoundController</name>
-    <message>
-        <source>Select one or more devices</source>
-        <translation>Seleccioneu un o més dispositius</translation>
-    </message>
-</context>
 <context>
     <name>QvkHelp</name>
     <message>
@@ -117,6 +95,17 @@
         <translation>Instal·leu un gestor de fitxers.</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>No s’ha trobat cap gestor de fitxers.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Instal·leu un gestor de fitxers.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -190,6 +179,14 @@
         <source>Donate</source>
         <translation>Feu una donació</translation>
     </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>No s’ha trobat cap gestor de fitxers.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Instal·leu un gestor de fitxers.</translation>
+    </message>
 </context>
 <context>
     <name>QvkPulseAudioWatcher</name>
@@ -198,6 +195,13 @@
         <translation>Seleccioneu un o més dispositius</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Seleccioneu un o més dispositius</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -485,18 +489,6 @@
         <source>Gray</source>
         <translation>Gris</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>Ctrl+Majús.+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>Ctrl+Majús.+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>Ctrl+Majús.+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>Reprodueix el darrer enregistrament</translation>
@@ -505,10 +497,6 @@
         <source>Open folder</source>
         <translation>Obre una carpeta</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>Ctrl+Majús.+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>Minimitza en iniciar l&apos;enregistrament</translation>
@@ -696,18 +684,6 @@
         <source>Stop</source>
         <translation>Atura</translation>
     </message>
-    <message>
-        <source>Pause</source>
-        <translation>Pausa</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Continua</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Reprodueix</translation>
-    </message>
     <message>
         <source>Folder</source>
         <translation>Carpeta</translation>
@@ -716,6 +692,66 @@
         <source>Do not record mouse cursor</source>
         <translation>No enregistris el cursor del ratolí</translation>
     </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>Còdec de l&apos;àudio</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>Camí del vídeo</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>Compte enrere</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>Ajuda</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Invertida</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Gris</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Blanc i negre</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Càmera</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Gir vertical</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Gir horizontal</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Elimina el marc de la finestra</translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation>Segona espera abans d&apos;enregistrar</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>Reinicia</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Oculta aquesta finestra</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Segons d&apos;espera abans de l&apos;enregistrament</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
