@@ -7,17 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>Kamera</translation>
-    </message>
-</context>
-<context>
-    <name>QvkCameraSettingsDialog</name>
-    <message>
-        <source>Camera settings</source>
-        <translation>Nastavení kamery</translation>
+        <source>Select one or more devices</source>
+        <translation>Vyberte jedno nebo více zařízení</translation>
     </message>
 </context>
 <context>
@@ -57,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>Přepnout do okna</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>Přepnout na celou obrazovku</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>Kamera</translation>
@@ -92,13 +77,6 @@
         <translation>Dialog</translation>
     </message>
 </context>
-<context>
-    <name>QvkDirectSoundController</name>
-    <message>
-        <source>Select one or more devices</source>
-        <translation>Vyberte jedno nebo více zařízení</translation>
-    </message>
-</context>
 <context>
     <name>QvkHelp</name>
     <message>
@@ -117,6 +95,17 @@
         <translation>Prosím o instalaci správce souborů.</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Nebyl nalezen žádný správce souborů.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Prosím o instalaci správce souborů.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -190,6 +179,14 @@
         <source>Donate</source>
         <translation>Podpořit</translation>
     </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Nebyl nalezen žádný správce souborů.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Prosím o instalaci správce souborů.</translation>
+    </message>
 </context>
 <context>
     <name>QvkPulseAudioWatcher</name>
@@ -198,6 +195,13 @@
         <translation>Vyberte jedno nebo více zařízení</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Vyberte jedno nebo více zařízení</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -485,18 +489,6 @@
         <source>Gray</source>
         <translation>Šedý</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+SHIFT+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+SHIFT+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+SHIFT+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>Přehrát poslední záznam</translation>
@@ -505,10 +497,6 @@
         <source>Open folder</source>
         <translation>Otevřít adresář</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>CTRL+SHIFT+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>Minimalizovat před začátkem nahrávání</translation>
@@ -607,10 +595,7 @@
     </message>
     <message>
         <source>Seconds wait before recording</source>
-        <translation>Vteřin počkej před nahráváním  - The best by me.
-Vteřin počkat před nahráváním??
-Sekund počkej před natáčením??
-Sekund počkej před záznamem??</translation>
+        <translation>Vteřin počkej před nahráváním</translation>
     </message>
     <message>
         <source>Window</source>
@@ -699,18 +684,6 @@ Sekund počkej před záznamem??</translation>
         <source>Stop</source>
         <translation>Stop</translation>
     </message>
-    <message>
-        <source>Pause</source>
-        <translation>Pauza</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Pokračovat</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Přehrát</translation>
-    </message>
     <message>
         <source>Folder</source>
         <translation>Adresář</translation>
@@ -719,6 +692,66 @@ Sekund počkej před záznamem??</translation>
         <source>Do not record mouse cursor</source>
         <translation>Nenahrávat kurzor myši</translation>
     </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>Audiokodek</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>Cesta k videosekvenci</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>Odpočítávání</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>Nápověda</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Invertovat</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Šedý</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Černá a bílá</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Překlopit svisle</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Překlopit vodorovně</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Odstranit rám okna</translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation>Druhé čekání před nahráváním</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>Obnovit</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Skrýt toto okno</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Vteřin počkej před nahráváním</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
