@@ -7,17 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>Κάμερα</translation>
-    </message>
-</context>
-<context>
-    <name>QvkCameraSettingsDialog</name>
-    <message>
-        <source>Camera settings</source>
-        <translation>Ρυθμίσεις Κάμερας</translation>
+        <source>Select one or more devices</source>
+        <translation>Επιλογή μιας ή περισσότερων συσκευών</translation>
     </message>
 </context>
 <context>
@@ -57,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>Εναλλαγή σε Παράθυρο</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>Εναλλαγή σε Πλήρη οθόνη</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>Κάμερα</translation>
@@ -92,13 +77,6 @@
         <translation>Διάλογος</translation>
     </message>
 </context>
-<context>
-    <name>QvkDirectSoundController</name>
-    <message>
-        <source>Select one or more devices</source>
-        <translation>Επιλογή μιας ή περισσότερων συσκευών</translation>
-    </message>
-</context>
 <context>
     <name>QvkHelp</name>
     <message>
@@ -117,6 +95,17 @@
         <translation>Παρακαλώ εγκαταστήστε ένα διαχειριστή αρχείων.</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Δε βρέθηκε διαχειριστής αρχείων.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Παρακαλώ εγκαταστήστε ένα διαχειριστή αρχείων.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -190,6 +179,14 @@
         <source>Donate</source>
         <translation>Δωρεά</translation>
     </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Δε βρέθηκε διαχειριστής αρχείων.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Παρακαλώ εγκαταστήστε ένα διαχειριστή αρχείων.</translation>
+    </message>
 </context>
 <context>
     <name>QvkPulseAudioWatcher</name>
@@ -198,6 +195,13 @@
         <translation>Επιλογή μιας ή περισσότερων συσκευών</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Επιλογή μιας ή περισσότερων συσκευών</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -485,18 +489,6 @@
         <source>Gray</source>
         <translation>Γκρι</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+SHIFT+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+SHIFT+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+SHIFT+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>Αναπαραγωγή τελευταίας εγγραφής</translation>
@@ -505,10 +497,6 @@
         <source>Open folder</source>
         <translation>Άνοιγμα φακέλου</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>CTRL+SHIFT+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>Ελαχιστοποίηση όταν ξεκινά η εγγραφή</translation>
@@ -696,18 +684,6 @@
         <source>Stop</source>
         <translation>Διακοπή</translation>
     </message>
-    <message>
-        <source>Pause</source>
-        <translation>Παύση</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Συνέχιση</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Αναπαραγωγή</translation>
-    </message>
     <message>
         <source>Folder</source>
         <translation>Φάκελος</translation>
@@ -716,6 +692,66 @@
         <source>Do not record mouse cursor</source>
         <translation>Μην καταγράφεις τον κέρσορα</translation>
     </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>Κωδικοποιητής ήχου</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>Τοποθεσία αρχείου</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>Αντίστροφη μέτρηση</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>Βοήθεια</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Αντιστροφή</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Γκρι</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Ασπρόμαυρη</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Κάμερα</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Κάθετη περιστροφή</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Οριζόντια περιστροφή</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Αφαίρεσε το πλαίσιο παραθύρου</translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation>Δευτερόλεπτα αναμονής πριν την εγγραφή</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>Επαναφορά</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Κρύψιμο αυτού του παραθύρου</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Δευτερόλεπτα αναμονής πριν την έναρξη της εγγραφής</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
