@@ -7,10 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>Camera</translation>
+        <source>Select one or more devices</source>
+        <translation>Select one or more devices</translation>
     </message>
 </context>
 <context>
@@ -50,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>Switch to Window</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>Switch to Fullscreen</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>Camera</translation>
@@ -79,10 +71,10 @@
     </message>
 </context>
 <context>
-    <name>QvkDirectSoundController</name>
+    <name>QvkDirDialog</name>
     <message>
-        <source>Select one or more devices</source>
-        <translation>Select one or more devices</translation>
+        <source>Dialog</source>
+        <translation>Dialog</translation>
     </message>
 </context>
 <context>
@@ -103,6 +95,17 @@
         <translation>Please install a filemanager.</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>No filemanager found.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Please install a filemanager.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -132,14 +135,6 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Fullscreen</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>Window</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
@@ -166,6 +161,33 @@
         <translation>Donate</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>Sourcecode</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>Homepage</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>Translations</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>Donate</translation>
+    </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>No filemanager found.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Please install a filemanager.</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -173,6 +195,13 @@
         <translation>Select one or more devices</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Select one or more devices</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -356,10 +385,6 @@
         <source>Audiocodec</source>
         <translation>Audiocodec</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>Quality</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>Do not record mouse cursor</translation>
@@ -464,18 +489,6 @@
         <source>Gray</source>
         <translation>Grey</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+SHIFT+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+SHIFT+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+SHIFT+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>Play last record</translation>
@@ -484,10 +497,6 @@
         <source>Open folder</source>
         <translation>Open folder</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>CTRL+SHIFT+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>Minimized when recording starts</translation>
@@ -512,10 +521,6 @@
         <source>Remove window frame</source>
         <translation>Remove window frame</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>Donate</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>Reset all settings at the next start</translation>
@@ -592,6 +597,161 @@
         <source>Seconds wait before recording</source>
         <translation>Seconds wait before recording</translation>
     </message>
+    <message>
+        <source>Window</source>
+        <translation>Window</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Fullscreen</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>Copyright and license from pictures</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Create images of tabs </translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>License information</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>ON</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>OFF</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>Record Time:</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>Video size:</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>Free disk space:</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>Information</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>Window</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Fullscreen</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>Area</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>Videocodec</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>Frames</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Format</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>Available</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>Not available</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Start</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Stop</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Folder</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>Do not record mouse cursor</translation>
+    </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>Audiocodec</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>Videopath</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>Countdown</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>Help</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Invert</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Grey</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Black-and-white</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Camera</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Flip vertical</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Flip horizontal</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Remove window frame</translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation>Second wait before recording</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>Reset</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Hide this window</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Seconds wait before recording</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -601,7 +761,7 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>Play</translation>
@@ -614,29 +774,5 @@
         <source>Stop</source>
         <translation>Stop</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>Open File</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Fullscreen</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>Previous frame</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>Next frame</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>Mute</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>Move menu</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
