@@ -7,10 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>Cámara</translation>
+        <source>Select one or more devices</source>
+        <translation>Seleccione uno o más dispositivos</translation>
     </message>
 </context>
 <context>
@@ -50,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>Cambiar a ventana</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>Ir a pantalla completa</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>Cámara</translation>
@@ -79,10 +71,10 @@
     </message>
 </context>
 <context>
-    <name>QvkDirectSoundController</name>
+    <name>QvkDirDialog</name>
     <message>
-        <source>Select one or more devices</source>
-        <translation>Seleccione uno o más dispositivos</translation>
+        <source>Dialog</source>
+        <translation>Cuadro de diálogo</translation>
     </message>
 </context>
 <context>
@@ -103,6 +95,17 @@
         <translation>Instale un gestor de archivos.</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>No se encontró ningún gestor de archivos.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Instale un gestor de archivos.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -133,14 +136,6 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Pantalla completa</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>Ventana</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
@@ -167,6 +162,33 @@
         <translation>Donar</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>Código fuente</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>Sitio web</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>Traducciones</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>Donar</translation>
+    </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>No se encontró ningún gestor de archivos.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Instale un gestor de archivos.</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -174,6 +196,13 @@
         <translation>Seleccione uno o más dispositivos</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Seleccione uno o más dispositivos</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -357,10 +386,6 @@
         <source>Audiocodec</source>
         <translation>Códec de audio</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>Calidad</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>No grabar el puntero del ratón</translation>
@@ -466,18 +491,6 @@
         <source>Gray</source>
         <translation>Gris</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+SHIFT+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+SHIFT+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+SHIFT+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>Reproducir última grabación</translation>
@@ -486,10 +499,6 @@
         <source>Open folder</source>
         <translation>Abrir carpeta</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>Ctrl + Mayús + F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>Minimizar al empezar grabación</translation>
@@ -514,10 +523,6 @@
         <source>Remove window frame</source>
         <translation>Quitar marco de ventana</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>Donar</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>Restablecer todas las preferencias en el próximo inicio</translation>
@@ -594,6 +599,161 @@
         <source>Seconds wait before recording</source>
         <translation>Segundos en espera antes de grabar</translation>
     </message>
+    <message>
+        <source>Window</source>
+        <translation>Ventana</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Pantalla completa</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>Derechos de autor y licencia desde imágenes</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Crear imágenes de pestañas</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Información sobre la Licencia</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>Encender</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>Apagar</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>Tiempo de grabación:</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>Tamaño de vídeo:</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>Espacio en disco disponible:</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>Información</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>Ventana</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Pantalla completa</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>Área</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>Códec de vídeo</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>Fotogramas</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Formato</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>Disponible</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>No disponible</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Iniciar</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Detener</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Carpeta</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>No grabar el puntero del ratón</translation>
+    </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>Códec de audio</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>Ruta del vídeo</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>Cuenta regresiva</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>Ayuda</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Invertir</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Gris</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Blanco y negro</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Cámara</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Voltear verticalmente</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Voltear horizontalmente</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Quitar marco de ventana</translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation>Segundos de espera antes de grabar</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>Restablecer</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Ocultar esta ventana</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Segundos en espera antes de grabar</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -603,7 +763,7 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>Reproducir</translation>
@@ -616,29 +776,5 @@
         <source>Stop</source>
         <translation>Detener</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>Abrir archivo</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Pantalla completa</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>Fotograma anterior</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>Fotograma siguiente</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>Silenciar</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>Mover el menú</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
