@@ -7,17 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>Camara</translation>
-    </message>
-</context>
-<context>
-    <name>QvkCameraSettingsDialog</name>
-    <message>
-        <source>Camera settings</source>
-        <translation>Opciones de Camara</translation>
+        <source>Select one or more devices</source>
+        <translation>Seleccione uno o más dispositivos</translation>
     </message>
 </context>
 <context>
@@ -57,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>Cambiar a modo ventana</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>Cambiar a pantalla completa</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>Camara</translation>
@@ -92,13 +77,6 @@
         <translation>Dialogo</translation>
     </message>
 </context>
-<context>
-    <name>QvkDirectSoundController</name>
-    <message>
-        <source>Select one or more devices</source>
-        <translation>Seleccione uno o más dispositivos</translation>
-    </message>
-</context>
 <context>
     <name>QvkHelp</name>
     <message>
@@ -117,6 +95,17 @@
         <translation>Por favor, instale un administrador de archivos.</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Administrador de archivos no valido</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Por favor, instale un administrador de archivos.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -149,7 +138,7 @@
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
-        <translation>Administrador de archivos no valido</translation>
+        <translation>Administrador de archivos no encontrado.</translation>
     </message>
     <message>
         <source>Please install a filemanager.</source>
@@ -190,6 +179,14 @@
         <source>Donate</source>
         <translation>Donar</translation>
     </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Administrador de archivos no valido</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Por favor, instale un administrador de archivos.</translation>
+    </message>
 </context>
 <context>
     <name>QvkPulseAudioWatcher</name>
@@ -198,6 +195,13 @@
         <translation>Seleccione uno o más dispositivos</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Seleccione uno o más dispositivos</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -485,18 +489,6 @@
         <source>Gray</source>
         <translation>Gris</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+SHIFT+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+SHIFT+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+SHIFT+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>Reproducir la ultima grabación</translation>
@@ -505,10 +497,6 @@
         <source>Open folder</source>
         <translation>Abrir archivo</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>CTRL+SHIFT+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>Minimizar cuando comience la grabación</translation>
@@ -696,18 +684,6 @@
         <source>Stop</source>
         <translation>Detener</translation>
     </message>
-    <message>
-        <source>Pause</source>
-        <translation>Pausar</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Continuar</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Reproducir</translation>
-    </message>
     <message>
         <source>Folder</source>
         <translation>Carpeta</translation>
@@ -716,6 +692,66 @@
         <source>Do not record mouse cursor</source>
         <translation>No grabar el puntero del ratón</translation>
     </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>Códec de audio</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>Ruta del vídeo</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>Cuenta regresiva</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>Ayuda</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Invertir</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Gris</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Negro-y-blanco</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Cámara</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Giro vertical</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Giro horizontal</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Quitar el marco de la ventana</translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation>Segundo de espera antes de la grabación</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>Reiniciar</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Ocultar esta ventana</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Segundo de espera antes de la grabación</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
