@@ -7,10 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>Cámara</translation>
+        <source>Select one or more devices</source>
+        <translation>Elige uno o más dispositivos</translation>
     </message>
 </context>
 <context>
@@ -50,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>Pasar a la ventana</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>Cambiar a pantalla completa</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>Cámara</translation>
@@ -79,10 +71,10 @@
     </message>
 </context>
 <context>
-    <name>QvkDirectSoundController</name>
+    <name>QvkDirDialog</name>
     <message>
-        <source>Select one or more devices</source>
-        <translation>Elige uno o más dispositivos</translation>
+        <source>Dialog</source>
+        <translation>Diálogo</translation>
     </message>
 </context>
 <context>
@@ -103,6 +95,17 @@
         <translation>Por favor, instale un administrador de archivos.</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>No se encontró administrador de archivos</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Por favor, instale un administrador de archivos.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -134,14 +137,6 @@ El límite de espacio en disco se ha alcanzado.</translation>
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Pantalla completa</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>Ventana</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
@@ -168,6 +163,33 @@ El límite de espacio en disco se ha alcanzado.</translation>
         <translation>Donar</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>Código fuente</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>Sitio web</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>Traducciones</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>Donar</translation>
+    </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>No se encontró administrador de archivos</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Por favor, instale un administrador de archivos.</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -175,6 +197,13 @@ El límite de espacio en disco se ha alcanzado.</translation>
         <translation>Elige uno o más dispositivos</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Elige uno o más dispositivos</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -358,10 +387,6 @@ El límite de espacio en disco se ha alcanzado.</translation>
         <source>Audiocodec</source>
         <translation>Codec de audio</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>Calidad</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>No grabar el puntero del ratón</translation>
@@ -466,18 +491,6 @@ El límite de espacio en disco se ha alcanzado.</translation>
         <source>Gray</source>
         <translation>Gris</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+SHIFT+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+SHIFT+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+SHIFT+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>Reproducir la última grabación</translation>
@@ -486,10 +499,6 @@ El límite de espacio en disco se ha alcanzado.</translation>
         <source>Open folder</source>
         <translation>Abrir carpeta</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>CTRL+SHIFT+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>Minimizar cuando inicie la grabación</translation>
@@ -514,10 +523,6 @@ El límite de espacio en disco se ha alcanzado.</translation>
         <source>Remove window frame</source>
         <translation>Remover el marco de la ventana</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>Donar</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>Reiniciar todos los ajustes en el siguiente inicio</translation>
@@ -594,6 +599,161 @@ El límite de espacio en disco se ha alcanzado.</translation>
         <source>Seconds wait before recording</source>
         <translation>Segundos de espera antes de grabar</translation>
     </message>
+    <message>
+        <source>Window</source>
+        <translation>Ventana</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Pantalla completa</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>Derechos de autor y licencia desde imágenes</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Crear imágenes de pestañas </translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Información de la licencia</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>Encendido</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>Apagado</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>Tiempo de grabación</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>Tamaño del video:</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>Espacio libre en el disco</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>información</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>Ventana</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Pantalla completa</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>Área</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>Códec de vídeo</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>Cuadros</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Formato</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>Disponible</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>No disponible</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Iniciar</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Detener</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Carpeta</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>No grabar el puntero del ratón</translation>
+    </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>Codec de audio</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>Ubicación del vídeo</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>Conteo regresivo</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>Ayuda</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Invertir</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Gris</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Blanco y Negro</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Cámara</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Voltear verticalmente</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Voltear horizontalmente</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Remover el marco de la ventana</translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation>Segundos de espera antes de grabar</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>Reiniciar</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Ocultar esta ventana</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Segundos de espera antes de grabar</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -603,7 +763,7 @@ El límite de espacio en disco se ha alcanzado.</translation>
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>Reproducir</translation>
@@ -616,29 +776,5 @@ El límite de espacio en disco se ha alcanzado.</translation>
         <source>Stop</source>
         <translation>Detener</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>Abrir archivo</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Pantalla completa</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>Cuadro anterior</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>Siguiente cuadro</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>Silenciar</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>Mover menu</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
