@@ -7,10 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>Kamera</translation>
+        <source>Select one or more devices</source>
+        <translation>Hautatu gailu bat edo gehiago</translation>
     </message>
 </context>
 <context>
@@ -50,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>Aldatu leihora</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>Aldatu pantaila osora</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>Kamera</translation>
@@ -79,10 +71,10 @@
     </message>
 </context>
 <context>
-    <name>QvkDirectSoundController</name>
+    <name>QvkDirDialog</name>
     <message>
-        <source>Select one or more devices</source>
-        <translation>Hautatu gailu bat edo gehiago</translation>
+        <source>Dialog</source>
+        <translation>Elkarrizketa</translation>
     </message>
 </context>
 <context>
@@ -103,6 +95,17 @@
         <translation>Instalatu fitxategi-arakatzaile bat.</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Ez da fitxategi-arakatzailerik aurkitu</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Instalatu fitxategi-arakatzaile bat.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -132,14 +135,6 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Pantaila osoa</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>Leihoa</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
@@ -166,6 +161,33 @@
         <translation>Eman dirua</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>Iturburu-kodea</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>Hasiera-orria</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>Itzulpenak</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>Eman dirua</translation>
+    </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Ez da fitxategi-arakatzailerik aurkitu</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Instalatu fitxategi-arakatzaile bat.</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -173,6 +195,13 @@
         <translation>Hautatu gailu bat edo gehiago</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Hautatu gailu bat edo gehiago</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -356,10 +385,6 @@
         <source>Audiocodec</source>
         <translation>Audio-kodeka</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>Kalitatea</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>Ez grabatu saguaren erakuslea</translation>
@@ -464,18 +489,6 @@
         <source>Gray</source>
         <translation>Grisa</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+MAIUS+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+MAIUS+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+MAIUS+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>Erreproduzitu grabatutako azkena</translation>
@@ -484,10 +497,6 @@
         <source>Open folder</source>
         <translation>Ireki karpeta</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>CTRL+MAIUS+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>Minimizatu grabazioa hastean</translation>
@@ -512,10 +521,6 @@
         <source>Remove window frame</source>
         <translation>Kendu leihoaren markoa</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>Eman dirua</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>Leheneratu ezarpen guztiak abiatzen den hurrengoan</translation>
@@ -592,6 +597,161 @@
         <source>Seconds wait before recording</source>
         <translation>Segundo hauen ondoren hasi grabatzen</translation>
     </message>
+    <message>
+        <source>Window</source>
+        <translation>Leihoa</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Pantaila osoa</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>Irudien gaineko copyrighta eta lizentzia</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Sortu fitxen irudiak</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Lizentziaren informazioa</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>PIZTU</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>ITZALI</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>Grabazio denbora:</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>Bideoaren tamaina:</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>Diskoko leku librea:</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>Informazioa</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>Leihoa</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Pantaila osoa</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>Eremua</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>Bideo-kodeka</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>Fotogramak</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Formatua</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>Eskuragarria</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>Ez eskuragarria</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Hasi</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Gelditu</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Karpeta</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>Ez grabatu saguaren erakuslea</translation>
+    </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>Audio-kodeka</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>Bideoaren bidea</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>Atzera-kontua</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>Laguntza</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Alderantzizkatu</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Grisa</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Zuri-beltza</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Irauli bertikalean</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Irauli horizontalean</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Kendu leihoaren markoa</translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation>Segundo hauen ondoren hasi grabatzen</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>Berrezarri</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Ezkutatu leiho hau</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Segundo hauen ondoren hasi grabatzen</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -601,7 +761,7 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>Erreproduzitu</translation>
@@ -614,29 +774,5 @@
         <source>Stop</source>
         <translation>Gelditu</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>Ireki fitxategia</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Pantaila osoa</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>Aurreko fotograma</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>Hurrengo fotograma</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>Mutu</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>Mugitu menua</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
