@@ -7,17 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>دوربین</translation>
-    </message>
-</context>
-<context>
-    <name>QvkCameraSettingsDialog</name>
-    <message>
-        <source>Camera settings</source>
-        <translation>تنظیمات دوربین</translation>
+        <source>Select one or more devices</source>
+        <translation>انتخاب یک یا چند دستگاه </translation>
     </message>
 </context>
 <context>
@@ -57,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>تغییر به حالت پنجره</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>تغییر به حالت تمام صفحه</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>دوربین</translation>
@@ -92,13 +77,6 @@
         <translation>گفتگو</translation>
     </message>
 </context>
-<context>
-    <name>QvkDirectSoundController</name>
-    <message>
-        <source>Select one or more devices</source>
-        <translation>انتخاب یک یا چند دستگاه </translation>
-    </message>
-</context>
 <context>
     <name>QvkHelp</name>
     <message>
@@ -117,6 +95,17 @@
         <translation>لطفا برنامه یک برنامه مدیریت فایل نصب کنید.</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>برنامه مدیریت فایل پیدا نشد.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>لطفا برنامه یک برنامه مدیریت فایل نصب کنید.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -192,6 +181,14 @@
         <source>Donate</source>
         <translation>حمایت</translation>
     </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>برنامه مدیریت فایل پیدا نشد.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>لطفا برنامه یک برنامه مدیریت فایل نصب کنید.</translation>
+    </message>
 </context>
 <context>
     <name>QvkPulseAudioWatcher</name>
@@ -200,6 +197,13 @@
         <translation>انتخاب یک یا چند دستگاه </translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>انتخاب یک یا چند دستگاه </translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -487,18 +491,6 @@
         <source>Gray</source>
         <translation>سیاه و سفید</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+SHIFT+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+SHIFT+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+SHIFT+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>پخش آخرین ویدیو ضبط شده</translation>
@@ -507,10 +499,6 @@
         <source>Open folder</source>
         <translation>باز کرده پوشه</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>CTRL+SHIFT+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>کوچک سازی هنگام شروع ضبط</translation>
@@ -698,18 +686,6 @@
         <source>Stop</source>
         <translation>پایان</translation>
     </message>
-    <message>
-        <source>Pause</source>
-        <translation>وقفه</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>ادامه</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>پخش</translation>
-    </message>
     <message>
         <source>Folder</source>
         <translation>پوشه</translation>
@@ -718,6 +694,66 @@
         <source>Do not record mouse cursor</source>
         <translation>نشانگر موس را ضبط نکن</translation>
     </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>کدک صدا</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>مسیر ویدیو</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>شمارنده</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>راهنما</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>معکوس کردن</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>خاکستری</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>سیاه و سفید</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>دوربین</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>عمودی چرخاندن</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>افقی چرخاندن</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>حذف فریم دور پنچره</translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation>ثانیه صبر کن قبل از شروع ضبط</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>بازنشانی</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>مخفی سازی پنجره</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>تعداد ثانیه‌هایی که باید قبل از شروع ضبط منتظر بمانید </translation>
+    </message>
 </context>
 <context>
     <name>license</name>
