@@ -7,17 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>Kamera</translation>
-    </message>
-</context>
-<context>
-    <name>QvkCameraSettingsDialog</name>
-    <message>
-        <source>Camera settings</source>
-        <translation>Kameran asetukset</translation>
+        <source>Select one or more devices</source>
+        <translation>Valitse yksi tai useampi laite</translation>
     </message>
 </context>
 <context>
@@ -57,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>Vaihda ikkunaan</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>Vaihda koko näyttöön</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>Kamera</translation>
@@ -92,13 +77,6 @@
         <translation>Valintaikkuna</translation>
     </message>
 </context>
-<context>
-    <name>QvkDirectSoundController</name>
-    <message>
-        <source>Select one or more devices</source>
-        <translation>Valitse yksi tai useampi laite</translation>
-    </message>
-</context>
 <context>
     <name>QvkHelp</name>
     <message>
@@ -117,6 +95,17 @@
         <translation>Asenna tiedostonhallinta. </translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Tiedostonhallintaa ei löytynyt.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Asenna tiedostonhallinta. </translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -190,6 +179,14 @@
         <source>Donate</source>
         <translation>Lahjoita</translation>
     </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Tiedostonhallintaa ei löytynyt.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Asenna tiedostonhallinta. </translation>
+    </message>
 </context>
 <context>
     <name>QvkPulseAudioWatcher</name>
@@ -198,6 +195,13 @@
         <translation>Valitse yksi tai useampi laite</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Valitse yksi tai useampi laite</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -485,18 +489,6 @@
         <source>Gray</source>
         <translation>Harmaa</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+SHIFT+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+SHIFT+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+SHIFT+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>Toista viimeisin tallennus</translation>
@@ -505,10 +497,6 @@
         <source>Open folder</source>
         <translation>Avaa kansio</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>CTRL+SHIFT+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>Pienennä kun tallennus alkaa</translation>
@@ -696,18 +684,6 @@
         <source>Stop</source>
         <translation>Lopeta</translation>
     </message>
-    <message>
-        <source>Pause</source>
-        <translation>Tauko</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Jatka</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Toista</translation>
-    </message>
     <message>
         <source>Folder</source>
         <translation>Kansio</translation>
@@ -716,6 +692,66 @@
         <source>Do not record mouse cursor</source>
         <translation>Älä tallenna hiiren osoitinta</translation>
     </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>Audiokoodekki</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>Videon polku</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>Lähtölaskenta</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>Ohje</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Käänteinen</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Harmaa</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Mustavalkoinen</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Käännä pystysuunnassa</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Käännä vaakasuunnassa</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Poista ikkunakehys</translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation>Sekuntia odotusta ennen tallennusta</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>Nollaa</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Piilota tämä ikkuna</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Odotusaika ennen tallennusta</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
