@@ -7,17 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>Caméra</translation>
-    </message>
-</context>
-<context>
-    <name>QvkCameraSettingsDialog</name>
-    <message>
-        <source>Camera settings</source>
-        <translation>Configuration caméra</translation>
+        <source>Select one or more devices</source>
+        <translation>Sélectionnez un ou plusieurs appareils</translation>
     </message>
 </context>
 <context>
@@ -57,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>Mode fenêtré</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>Mode plein écran</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>Caméra</translation>
@@ -92,13 +77,6 @@
         <translation>Dialogue</translation>
     </message>
 </context>
-<context>
-    <name>QvkDirectSoundController</name>
-    <message>
-        <source>Select one or more devices</source>
-        <translation>Sélectionnez un ou plusieurs fichiers</translation>
-    </message>
-</context>
 <context>
     <name>QvkHelp</name>
     <message>
@@ -117,6 +95,17 @@
         <translation>Veuillez installer un gestionnaire de fichiers.</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Aucun gestionnaire de fichiers trouvé.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Veuillez installer un gestionnaire de fichiers.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -190,6 +179,14 @@
         <source>Donate</source>
         <translation>Faire un don</translation>
     </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Aucun gestionnaire de fichiers trouvé.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Veuillez installer un gestionnaire de fichiers.</translation>
+    </message>
 </context>
 <context>
     <name>QvkPulseAudioWatcher</name>
@@ -198,6 +195,13 @@
         <translation>Sélectionnez un ou plusieurs fichiers</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Sélectionnez un ou plusieurs appareils</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -485,18 +489,6 @@
         <source>Gray</source>
         <translation>Gris</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+SHIFT+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+SHIFT+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+SHIFT+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>Jouer le dernier enregistrement</translation>
@@ -505,10 +497,6 @@
         <source>Open folder</source>
         <translation>Ouvrir dossier</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>CTRL+SHIFT+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>Minimisé à l&apos;enregistrement</translation>
@@ -696,18 +684,6 @@
         <source>Stop</source>
         <translation>Arrêter</translation>
     </message>
-    <message>
-        <source>Pause</source>
-        <translation>Pause</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Continuer</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Lire</translation>
-    </message>
     <message>
         <source>Folder</source>
         <translation>Dossier</translation>
@@ -716,6 +692,66 @@
         <source>Do not record mouse cursor</source>
         <translation>Ne pas enregistrer le curseur de la souris</translation>
     </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>Codec audio</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>Chemin d&apos;enregistrement de la vidéo</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>Compte à rebours</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>Aide</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Inverser</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Gris</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Noir-et-blanc</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Caméra</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Retourner verticalement</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Retourner horizontalement</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Supprimer le cadre de la fenêtre </translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation>Secondes d&apos;attentes avant le début d&apos;enregistrement</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>Remettre à zéro les réglages</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Masquer cette fenêtre</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Secondes d&apos;attente avant l&apos;enregistrement</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
