@@ -7,10 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>Kamera</translation>
+        <source>Select one or more devices</source>
+        <translation>Odaberi jedan ili više uređaja</translation>
     </message>
 </context>
 <context>
@@ -50,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>Prebaci na prozor</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>Prebaci na cijeli zaslon</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>Kamera</translation>
@@ -79,10 +71,10 @@
     </message>
 </context>
 <context>
-    <name>QvkDirectSoundController</name>
+    <name>QvkDirDialog</name>
     <message>
-        <source>Select one or more devices</source>
-        <translation>Odaberi jedan ili više uređaja</translation>
+        <source>Dialog</source>
+        <translation>Dijalog</translation>
     </message>
 </context>
 <context>
@@ -104,6 +96,18 @@
         <translation>Molim instalirajte filemanager</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Upravitelj datoteka nije pronađen. 
+ </translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Molim instalirajte filemanager</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -133,15 +137,6 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation> 
-Puni zaslon </translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>Prozor</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
@@ -169,6 +164,34 @@ Puni zaslon </translation>
         <translation>Donirajte</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>Izvorni kod </translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>Početna stranica </translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>Prijevodi </translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>Donirajte</translation>
+    </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Upravitelj datoteka nije pronađen. 
+ </translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Molim instalirajte filemanager</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -176,6 +199,13 @@ Puni zaslon </translation>
         <translation>Odaberi jedan ili više uređaja</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Odaberi jedan ili više uređaja</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -360,10 +390,6 @@ Puni zaslon </translation>
         <source>Audiocodec</source>
         <translation>Audiokodek</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>Kvaliteta</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>Ne snimaj kursor miša </translation>
@@ -468,18 +494,6 @@ Puni zaslon </translation>
         <source>Gray</source>
         <translation>Sivo</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+SHIFT+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+SHIFT+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+SHIFT+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>Reproduciraj posljednji zapis</translation>
@@ -488,10 +502,6 @@ Puni zaslon </translation>
         <source>Open folder</source>
         <translation>Otvori mapu</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>CTRL+SHIFT+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>Minimizirano prilikom pokretanja snimanja</translation>
@@ -516,10 +526,6 @@ Puni zaslon </translation>
         <source>Remove window frame</source>
         <translation>Uklonite okvir prozora</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>Donirajte</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>Vrati sve postavke na sljedeći početak</translation>
@@ -596,6 +602,161 @@ Puni zaslon </translation>
         <source>Seconds wait before recording</source>
         <translation>Sekunde čekanja prije snimanja </translation>
     </message>
+    <message>
+        <source>Window</source>
+        <translation>Prozor</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Puni zaslon </translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>Autorska prava i licenca sa slika</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Stvorite slike kartica </translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Podaci o licenci </translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>Ukljućeno</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>Isključeno</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>Vrijeme snimanja: </translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>Veličina videozapisa: </translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>Slobodan prostor na disku: </translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>Informacija </translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>Prozor</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Puni zaslon </translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>Površina</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>Videokodek</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>Okviri</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Format</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>Dostupno</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>Nije dostupno</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Pokreni</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Zaustavi</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Mapa</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>Ne snimaj kursor miša </translation>
+    </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>Audiokodek</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>Video-put</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>Odbrojavanje </translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>Pomoć</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Izokreni</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Sivo</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Crno-bijelo</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Okrenite okomito </translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Okreni vodoravno</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Uklonite okvir prozora</translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation>Drugo čekanje prije snimanja </translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>Resetiraj</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Sakrij ovaj prozor </translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Sekunde čekanja prije snimanja </translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -605,7 +766,7 @@ Puni zaslon </translation>
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>Pokreni</translation>
@@ -618,29 +779,5 @@ Puni zaslon </translation>
         <source>Stop</source>
         <translation>Zaustavi</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>Otvorena datoteka </translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Puni zaslon </translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>Prethodni okvir </translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>Sljedeći kadar</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>Isključi zvuk </translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>Premjesti izbornik </translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
