@@ -7,17 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>Kamera</translation>
-    </message>
-</context>
-<context>
-    <name>QvkCameraSettingsDialog</name>
-    <message>
-        <source>Camera settings</source>
-        <translation>Pengaturan Kamera</translation>
+        <source>Select one or more devices</source>
+        <translation>Pilih satu atau lebih perangkat</translation>
     </message>
 </context>
 <context>
@@ -57,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>Beralih ke Jendela</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>Beralih ke Layar Penuh</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>Kamera</translation>
@@ -92,13 +77,6 @@
         <translation>Percakapan</translation>
     </message>
 </context>
-<context>
-    <name>QvkDirectSoundController</name>
-    <message>
-        <source>Select one or more devices</source>
-        <translation>Pilih satu atau lebih perangkat</translation>
-    </message>
-</context>
 <context>
     <name>QvkHelp</name>
     <message>
@@ -117,6 +95,17 @@
         <translation>Silakan instal pengelola file.</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Tidak ada pengelola file yang ditemukan.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Silakan instal pengelola file.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -190,6 +179,14 @@
         <source>Donate</source>
         <translation>Donasi</translation>
     </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Tidak ada pengelola file yang ditemukan.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Silakan instal pengelola file.</translation>
+    </message>
 </context>
 <context>
     <name>QvkPulseAudioWatcher</name>
@@ -198,6 +195,13 @@
         <translation>Pilih satu atau lebih perangkat</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Pilih satu atau lebih perangkat</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -485,18 +489,6 @@
         <source>Gray</source>
         <translation>Abu-abu</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+SHIFT+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+SHIFT+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+SHIFT+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>Putar rekaman terakhir</translation>
@@ -505,10 +497,6 @@
         <source>Open folder</source>
         <translation>Buka folder</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>CTRL+SHIFT+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>Minimalkan jendela saat perekaman dimulai</translation>
@@ -696,18 +684,6 @@
         <source>Stop</source>
         <translation>Berhenti</translation>
     </message>
-    <message>
-        <source>Pause</source>
-        <translation>Jeda</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Lanjutkan</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Mainkan</translation>
-    </message>
     <message>
         <source>Folder</source>
         <translation>Folder</translation>
@@ -716,6 +692,66 @@
         <source>Do not record mouse cursor</source>
         <translation>Jangan rekam kursor mouse</translation>
     </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>AudioCodec</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>Videopath</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>Hitung Mundur</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>Bantuan</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Membalikkan</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Abu-abu</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Hitam-dan-Putih</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Balik vertikal</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Balik horizontal</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Hapus bingkai jendela</translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation>Tunggu kedua sebelum merekam</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>Atur Ulang</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Sembunyikan jendela ini</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Beberapa detik menunggu sebelum merekam</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
