@@ -7,17 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>Webcam</translation>
-    </message>
-</context>
-<context>
-    <name>QvkCameraSettingsDialog</name>
-    <message>
-        <source>Camera settings</source>
-        <translation>Impostazioni camera</translation>
+        <source>Select one or more devices</source>
+        <translation>Seleziona uno o più dispositivi</translation>
     </message>
 </context>
 <context>
@@ -57,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>Passa a Finestra</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>Passa a Schermo Intero</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>Webcam</translation>
@@ -92,13 +77,6 @@
         <translation>Finestra di dialogo Impostazioni fotocamera</translation>
     </message>
 </context>
-<context>
-    <name>QvkDirectSoundController</name>
-    <message>
-        <source>Select one or more devices</source>
-        <translation>Seleziona uno o più dispositivi</translation>
-    </message>
-</context>
 <context>
     <name>QvkHelp</name>
     <message>
@@ -117,6 +95,17 @@
         <translation>Installa un filemanager.</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Filemanager non trovato.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Si prega di installare un filemanager.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -190,6 +179,14 @@
         <source>Donate</source>
         <translation>Fai una donazione</translation>
     </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Filemanager non trovato.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Si prega di installare un filemanager.</translation>
+    </message>
 </context>
 <context>
     <name>QvkPulseAudioWatcher</name>
@@ -198,6 +195,13 @@
         <translation>Seleziona uno o più dispositivi</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Seleziona uno o più dispositivi</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -485,18 +489,6 @@
         <source>Gray</source>
         <translation>Grigio</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+SHIFT+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+SHIFT+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+SHIFT+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>Riproduci ultima registrazione</translation>
@@ -505,10 +497,6 @@
         <source>Open folder</source>
         <translation>Apri cartella</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>CTRL+SHIFT+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>Ridotto a icona durante la registrazione</translation>
@@ -696,18 +684,6 @@
         <source>Stop</source>
         <translation>Ferma</translation>
     </message>
-    <message>
-        <source>Pause</source>
-        <translation>Pausa</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Continua</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Riproduci</translation>
-    </message>
     <message>
         <source>Folder</source>
         <translation>Cartella</translation>
@@ -716,6 +692,66 @@
         <source>Do not record mouse cursor</source>
         <translation>Non registrare il cursore del mouse</translation>
     </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>Codificatore audio</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>Salva in</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>Avvio ritardo di</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>Aiuto</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Inverti</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Grigio</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Bianco e nero</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Webcam</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Capovolgi verticale</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Capovolgi orizzontale</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Rimuovi bordo finestra</translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation>Secondi di attesa prima di registrare</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>Ripristina</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Nascondi questa finestra</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Secondi di attesa prima di registrare</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
