@@ -7,17 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>カメラ</translation>
-    </message>
-</context>
-<context>
-    <name>QvkCameraSettingsDialog</name>
-    <message>
-        <source>Camera settings</source>
-        <translation>カメラの設定</translation>
+        <source>Select one or more devices</source>
+        <translation>一つ以上のデバイスを選択</translation>
     </message>
 </context>
 <context>
@@ -57,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>ウィンドウ表示</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>全画面表示</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>カメラ</translation>
@@ -92,13 +77,6 @@
         <translation>ダイアログ</translation>
     </message>
 </context>
-<context>
-    <name>QvkDirectSoundController</name>
-    <message>
-        <source>Select one or more devices</source>
-        <translation>一つ以上のデバイスを選択</translation>
-    </message>
-</context>
 <context>
     <name>QvkHelp</name>
     <message>
@@ -117,6 +95,17 @@
         <translation>ファイルマネージャーをインストールしてください</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>ファイルマネージャーが見つかりません</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>ファイルマネージャーをインストールしてください</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -190,6 +179,14 @@
         <source>Donate</source>
         <translation>寄付</translation>
     </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>ファイルマネージャーが見つかりません</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>ファイルマネージャーをインストールしてください</translation>
+    </message>
 </context>
 <context>
     <name>QvkPulseAudioWatcher</name>
@@ -198,6 +195,13 @@
         <translation>一つ以上のデバイスを選択</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>一つ以上のデバイスを選択</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -485,18 +489,6 @@
         <source>Gray</source>
         <translation>グレー</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+SHIFT+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+SHIFT+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+SHIFT+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>最後の録画を再生する</translation>
@@ -505,10 +497,6 @@
         <source>Open folder</source>
         <translation>フォルダーを開く</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>CTRL+SHIFT+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>録画開始時に最小化</translation>
@@ -696,18 +684,6 @@
         <source>Stop</source>
         <translation>停止</translation>
     </message>
-    <message>
-        <source>Pause</source>
-        <translation>一時停止</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>持続する</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>再生</translation>
-    </message>
     <message>
         <source>Folder</source>
         <translation>フォルダー</translation>
@@ -716,6 +692,66 @@
         <source>Do not record mouse cursor</source>
         <translation>マウスカーソルを録画しない</translation>
     </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>音声コーデック</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>ビデオ保存パス</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>カウントダウン</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>ヘルプ</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>ネガポジ反転</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>グレー</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>白黒</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>カメラ</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>垂直反転</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>水平反転</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>ウィンドウ枠非表示</translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation>録画前の秒数</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>リセット</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>このウィンドウを隠す</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>記録開始までの待機秒数</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
