@@ -7,10 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>카메라</translation>
+        <source>Select one or more devices</source>
+        <translation>1개 이상의 장치 선택</translation>
     </message>
 </context>
 <context>
@@ -50,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>창으로 전환</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>전체화면 전환</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>카메라</translation>
@@ -71,18 +63,18 @@
     </message>
     <message>
         <source>Close this window and start vokoscreenNG again.</source>
-        <translation>창을 닫고 vokoscreenNG를 다시 시작해 주세요.</translation>
+        <translation>이 창을 닫고 vokoscreenNG를 다시 시작해 주세요.</translation>
     </message>
     <message>
         <source>Have fun with vokoscreenNG</source>
-        <translation>vovkoscreenNG와 함께 즐겨요</translation>
+        <translation>vovkoscreenNG로 즐겨보세요</translation>
     </message>
 </context>
 <context>
-    <name>QvkDirectSoundController</name>
+    <name>QvkDirDialog</name>
     <message>
-        <source>Select one or more devices</source>
-        <translation>1개 이상의 장치 선택</translation>
+        <source>Dialog</source>
+        <translation>대화창</translation>
     </message>
 </context>
 <context>
@@ -96,7 +88,18 @@
     <name>QvkImageFromTabs</name>
     <message>
         <source>No filemanager found.</source>
-        <translation>파일 탐색기가 없습니다.</translation>
+        <translation>파일탐색기가 없습니다.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>파일탐색기를 설치해 주세요.</translation>
+    </message>
+</context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>파일탐색기가 없습니다.</translation>
     </message>
     <message>
         <source>Please install a filemanager.</source>
@@ -111,39 +114,31 @@
     </message>
     <message>
         <source>The recording is not started, not enough free disk space.</source>
-        <translation>여유 디스크 공간이 충분하지 않아서, 녹화를 시작하지 않았습니다.</translation>
+        <translation>디스크 여유 공간이 충분하지 않아서, 녹화를 시작하지 않았습니다.</translation>
     </message>
     <message>
         <source>The free disk space limit is reached.</source>
-        <translation>여유 디스크 공간이 부족합니다.</translation>
+        <translation>디스크 여유 공간이 부족합니다.</translation>
     </message>
     <message>
         <source>Limit of free disk space</source>
-        <translation>여유 디스크 공간 제한</translation>
+        <translation>디스크 여유 공간 제한</translation>
     </message>
     <message>
         <source>Megabyte</source>
-        <translation>메가바이트</translation>
+        <translation>MB</translation>
     </message>
     <message>
         <source>The recording was stopped, not enough free disk space.</source>
-        <translation>여유 디스크 공간이 충분하지 않아서, 녹화가 중단됐습니다.</translation>
+        <translation>디스크 여유 공간이 충분하지 않아서, 녹화가 중단됐습니다.</translation>
     </message>
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>전체화면</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>창</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
-        <translation>파일 탐색기가 없습니다.</translation>
+        <translation>파일탐색기가 없습니다.</translation>
     </message>
     <message>
         <source>Please install a filemanager.</source>
@@ -166,6 +161,33 @@
         <translation>후원하기</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>소스코드</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>홈페이지</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>번역</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>후원하기</translation>
+    </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>파일탐색기가 없습니다.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>파일탐색기를 설치해 주세요.</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -173,6 +195,13 @@
         <translation>1개 이상의 장치 선택</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>1개 이상의 장치 선택</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -191,7 +220,7 @@
     <name>QvkSnapshot</name>
     <message>
         <source>No filemanager found.</source>
-        <translation>파일 탐색기가 없습니다.</translation>
+        <translation>파일탐색기가 없습니다.</translation>
     </message>
     <message>
         <source>Please install a filemanager.</source>
@@ -322,11 +351,11 @@
     </message>
     <message>
         <source>Video size:</source>
-        <translation>비디오 크기:</translation>
+        <translation>영상 크기:</translation>
     </message>
     <message>
         <source>Free disk space:</source>
-        <translation>남는 디스크 공간:</translation>
+        <translation>디스크 여유 공간:</translation>
     </message>
     <message>
         <source>Information</source>
@@ -342,11 +371,11 @@
     </message>
     <message>
         <source>Frames</source>
-        <translation>프레임수</translation>
+        <translation>프레임 수</translation>
     </message>
     <message>
         <source>Videocodec</source>
-        <translation>영상코덱</translation>
+        <translation>영상 코덱</translation>
     </message>
     <message>
         <source>Format</source>
@@ -354,11 +383,7 @@
     </message>
     <message>
         <source>Audiocodec</source>
-        <translation>음성코덱</translation>
-    </message>
-    <message>
-        <source>Quality</source>
-        <translation>품질</translation>
+        <translation>음성 코덱</translation>
     </message>
     <message>
         <source>Do not record mouse cursor</source>
@@ -398,11 +423,11 @@
     </message>
     <message>
         <source>Limit of free disk space</source>
-        <translation>사용 가능한 디스크 공간 제한</translation>
+        <translation>디스크 여유 공간 제한</translation>
     </message>
     <message>
         <source>Show in systray</source>
-        <translation>트레이에 표시하기</translation>
+        <translation>시스템 트레이에 표시하기</translation>
     </message>
     <message>
         <source>Second wait before recording</source>
@@ -464,18 +489,6 @@
         <source>Gray</source>
         <translation>회색</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+SHIFT+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+SHIFT+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+SHIFT+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>마지막 녹화 재생</translation>
@@ -484,10 +497,6 @@
         <source>Open folder</source>
         <translation>폴더 열기</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>CTRL+SHIFT+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>녹화 시작할 때 창 최소화</translation>
@@ -512,10 +521,6 @@
         <source>Remove window frame</source>
         <translation>창틀 제거</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>후원하기</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>다음 시작시 모든 설정 초기화</translation>
@@ -592,6 +597,161 @@
         <source>Seconds wait before recording</source>
         <translation>몇 초 후 녹화 시작</translation>
     </message>
+    <message>
+        <source>Window</source>
+        <translation>창</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>전체화면</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>이미지의 저작권과 라이선스</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>탭 이미지 만들기</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>라이선스 정보</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>ON</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>OFF</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>녹화 시간:</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>영상 크기:</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>디스크 여유 공간:</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>정보</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>창</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>전체화면</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>영역</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>영상 코덱</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>프레임 수</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>포맷</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>사용가능</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>사용불가</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>시작</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>중지</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>폴더</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>마우스 커서 녹화하지 않기</translation>
+    </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>음성 코덱</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>영상 경로</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>카운트다운</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>도움말</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>반전</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>회색</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>흑백</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>카메라</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>상하 뒤집기</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>좌우 뒤집기</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>창틀 제거</translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation>몇 초 후 녹화 시작</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>초기화</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>이 창 숨기기</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>몇 초 후 녹화 시작</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -601,7 +761,7 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>재생</translation>
@@ -614,29 +774,5 @@
         <source>Stop</source>
         <translation>중지</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>파일 열기</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>전체화면</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>이전 프레임</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>다음 프레임</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>음소거</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>메뉴 이동하기</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
