@@ -7,17 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>Kamera</translation>
-    </message>
-</context>
-<context>
-    <name>QvkCameraSettingsDialog</name>
-    <message>
-        <source>Camera settings</source>
-        <translation>Kameros nustatymai</translation>
+        <source>Select one or more devices</source>
+        <translation>Pasirinkite vieną ar daugiau įrenginių</translation>
     </message>
 </context>
 <context>
@@ -57,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>Perjungti į langą</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>Perjungti į visą ekraną</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>Kamera</translation>
@@ -92,13 +77,6 @@
         <translation>Dialogas</translation>
     </message>
 </context>
-<context>
-    <name>QvkDirectSoundController</name>
-    <message>
-        <source>Select one or more devices</source>
-        <translation>Pasirinkite vieną ar daugiau įrenginių</translation>
-    </message>
-</context>
 <context>
     <name>QvkHelp</name>
     <message>
@@ -117,6 +95,17 @@
         <translation>Įdiekite failų tvarkytuvę.</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Nerasta jokios failų tvarkytuvės.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Įdiekite failų tvarkytuvę.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -190,6 +179,14 @@
         <source>Donate</source>
         <translation>Paaukoti</translation>
     </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Nerasta jokios failų tvarkytuvės.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Įdiekite failų tvarkytuvę.</translation>
+    </message>
 </context>
 <context>
     <name>QvkPulseAudioWatcher</name>
@@ -198,6 +195,13 @@
         <translation>Pasirinkite vieną ar daugiau įrenginių</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Pasirinkite vieną ar daugiau įrenginių</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -485,18 +489,6 @@
         <source>Gray</source>
         <translation>Pilka</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>VALD+LYG2+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>VALD+LYG2+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>VALD+LYG2+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>Groti paskiausią įrašą</translation>
@@ -505,10 +497,6 @@
         <source>Open folder</source>
         <translation>Atverti aplanką</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>VALD+LYG2+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>Prasidėjus įrašinėjimui, suskleisti</translation>
@@ -696,18 +684,6 @@
         <source>Stop</source>
         <translation>Stabdyti</translation>
     </message>
-    <message>
-        <source>Pause</source>
-        <translation>Pristabdyti</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Tęsti</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Groti</translation>
-    </message>
     <message>
         <source>Folder</source>
         <translation>Aplankas</translation>
@@ -716,6 +692,66 @@
         <source>Do not record mouse cursor</source>
         <translation>Neįrašinėti pelės žymeklio</translation>
     </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>Garso kodekas</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>Vaizdo įrašo kelias</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>Atvirkštinis skaičiavimas</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>Žinynas</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Invertuoti</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Pilka</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Juoda ir balta</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Apversti vertikaliai</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Apversti horizontaliai</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Šalinti lango rėmelį</translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation>Luktelėti sekundėlę prieš įrašinėjant</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>Atstatyti</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Slėpti šį langą</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Kiek sekundžių laukti, prieš įrašinėjant</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
