@@ -7,17 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>Kamera</translation>
-    </message>
-</context>
-<context>
-    <name>QvkCameraSettingsDialog</name>
-    <message>
-        <source>Camera settings</source>
-        <translation>Kamera instillinger</translation>
+        <source>Select one or more devices</source>
+        <translation>Velg én til flere enheter</translation>
     </message>
 </context>
 <context>
@@ -57,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>Bytt til vindu</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>Bytt til fullskjerm</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>Kamera</translation>
@@ -92,13 +77,6 @@
         <translation>Dialog</translation>
     </message>
 </context>
-<context>
-    <name>QvkDirectSoundController</name>
-    <message>
-        <source>Select one or more devices</source>
-        <translation>Velg én til flere enheter</translation>
-    </message>
-</context>
 <context>
     <name>QvkHelp</name>
     <message>
@@ -117,6 +95,17 @@
         <translation>Vennligst installere en filutforsker.</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Ingen filutforsker funnet.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Vennligst installere en filutforsker.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -190,6 +179,14 @@
         <source>Donate</source>
         <translation>Donasjon</translation>
     </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Ingen filutforsker funnet.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Vennligst installere en filutforsker.</translation>
+    </message>
 </context>
 <context>
     <name>QvkPulseAudioWatcher</name>
@@ -198,6 +195,13 @@
         <translation>Velg én til flere enheter</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Velg én til flere enheter</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -485,18 +489,6 @@
         <source>Gray</source>
         <translation>Grå</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+SHIFT+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+SHIFT+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+SHIFT+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>Spill av siste opptak</translation>
@@ -505,10 +497,6 @@
         <source>Open folder</source>
         <translation>Åpne mappe</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>CTRL+SHIFT+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>Minimert når opptak starter</translation>
@@ -696,18 +684,6 @@
         <source>Stop</source>
         <translation>Stoppe</translation>
     </message>
-    <message>
-        <source>Pause</source>
-        <translation>Pause</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Fortsett</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Spille</translation>
-    </message>
     <message>
         <source>Folder</source>
         <translation>Mappe</translation>
@@ -716,6 +692,66 @@
         <source>Do not record mouse cursor</source>
         <translation>ikke ta opp musepeker</translation>
     </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>Lydkodek</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>Video Sti</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>Nedtelling</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>Hjelp</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Invertere</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Grå</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Svart-hvit</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Snu vertikalt</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Snu horisontalt</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Fjern vindusramme</translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation>Sekund venting før opptak</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>Nullstille</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Skjul dette vinduet</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Sekunder venter før opptak</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
