@@ -7,17 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>Camera</translation>
-    </message>
-</context>
-<context>
-    <name>QvkCameraSettingsDialog</name>
-    <message>
-        <source>Camera settings</source>
-        <translation>Camera instellingen</translation>
+        <source>Select one or more devices</source>
+        <translation>Selecteer één of meer apparaten</translation>
     </message>
 </context>
 <context>
@@ -57,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>Vensterweergave</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>Schermvullende weergave</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>Camera</translation>
@@ -92,13 +77,6 @@
         <translation>Dialoogvenster</translation>
     </message>
 </context>
-<context>
-    <name>QvkDirectSoundController</name>
-    <message>
-        <source>Select one or more devices</source>
-        <translation>Selecteer één of meer apparaten</translation>
-    </message>
-</context>
 <context>
     <name>QvkHelp</name>
     <message>
@@ -117,6 +95,17 @@
         <translation>Installeer een bestandsbeheerder.</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Er is geen bestandsbeheerder aangetroffen.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Installeer een bestandsbeheerder.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -190,6 +179,14 @@
         <source>Donate</source>
         <translation>Doneren</translation>
     </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Er is geen bestandsbeheerder aangetroffen.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Installeer een bestandsbeheerder.</translation>
+    </message>
 </context>
 <context>
     <name>QvkPulseAudioWatcher</name>
@@ -198,6 +195,13 @@
         <translation>Selecteer één of meer apparaten</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Selecteer één of meer apparaten</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -485,18 +489,6 @@
         <source>Gray</source>
         <translation>Grijs</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+SHIFT+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+SHIFT+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+SHIFT+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>Laatste opname afspelen</translation>
@@ -505,10 +497,6 @@
         <source>Open folder</source>
         <translation>Map openen</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>CTRL+SHIFT+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>Minimaliseren zodra opname start</translation>
@@ -696,18 +684,6 @@
         <source>Stop</source>
         <translation>Stop</translation>
     </message>
-    <message>
-        <source>Pause</source>
-        <translation>Pauze</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Hervatten</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Afspelen</translation>
-    </message>
     <message>
         <source>Folder</source>
         <translation>Map</translation>
@@ -716,6 +692,66 @@
         <source>Do not record mouse cursor</source>
         <translation>Muis cursor niet opnemen</translation>
     </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>Audiocodec</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>Video map</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>Aftellen</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>Hulp</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Omkeren</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Grijs</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Zwart-wit</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Camera</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Verticaal spiegelen</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Horizontaal spiegelen</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Vensterrand verwijderen</translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation>Aantal seconden voordat opname start</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>Standaardwaarden</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Venster verbergen</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Aantal seconden voordat opname start</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
