@@ -3,14 +3,14 @@
     <name>QvkAudioController</name>
     <message>
         <source>Select one or more devices</source>
-        <translation>Selecteer één of meer apparaten</translation>
+        <translation>Selecteer een of meerdere apparaten</translation>
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>Camera</translation>
+        <source>Select one or more devices</source>
+        <translation>Selecteer een of meerdere apparaten</translation>
     </message>
 </context>
 <context>
@@ -50,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>Vensterweergave</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>Schermvullende weergave</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>Camera</translation>
@@ -79,10 +71,10 @@
     </message>
 </context>
 <context>
-    <name>QvkDirectSoundController</name>
+    <name>QvkDirDialog</name>
     <message>
-        <source>Select one or more devices</source>
-        <translation>Selecteer één of meer apparaten</translation>
+        <source>Dialog</source>
+        <translation>Dialoogvenster</translation>
     </message>
 </context>
 <context>
@@ -103,6 +95,17 @@
         <translation>Installeer een bestandsbeheerder.</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Er is geen bestandsbeheerder aangetroffen.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Installeer een bestandsbeheerder.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -132,14 +135,6 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Beeldvullend</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>Venster</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
@@ -166,11 +161,45 @@
         <translation>Doneren</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>Broncode</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>Website</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>Vertalingen</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>Doneren</translation>
+    </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Er is geen bestandsbeheerder aangetroffen.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Installeer een bestandsbeheerder.</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
         <source>Select one or more devices</source>
-        <translation>Selecteer één of meer apparaten</translation>
+        <translation>Selecteer een of meerdere apparaten</translation>
+    </message>
+</context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Selecteer een of meerdere apparaten</translation>
     </message>
 </context>
 <context>
@@ -264,7 +293,7 @@
     <name>QvkWASAPIController</name>
     <message>
         <source>Select one or more devices</source>
-        <translation>Selecteer één of meer apparaten</translation>
+        <translation>Selecteer een of meerdere apparaten</translation>
     </message>
 </context>
 <context>
@@ -356,10 +385,6 @@
         <source>Audiocodec</source>
         <translation>Audiocodec</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>Kwaliteit</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>Cursor verbergen</translation>
@@ -464,18 +489,6 @@
         <source>Gray</source>
         <translation>Grijs</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+SHIFT+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+SHIFT+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+SHIFT+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>Recentste opname afspelen</translation>
@@ -484,10 +497,6 @@
         <source>Open folder</source>
         <translation>Map openen</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>CTRL+SHIFT+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>Minimaliseren zodra opname start</translation>
@@ -512,10 +521,6 @@
         <source>Remove window frame</source>
         <translation>Vensterrand verwijderen</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>Doneren</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>Alle instellingen herstellen bij opnieuw opstarten</translation>
@@ -592,6 +597,161 @@
         <source>Seconds wait before recording</source>
         <translation>Aantal seconden voordat opname start</translation>
     </message>
+    <message>
+        <source>Window</source>
+        <translation>Venster</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Schermvullend</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>Copyright en licentie uit beelden</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Afbeeldingen maken van tabbladen</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Licentie-informatie</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>AAN</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>UIT</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>Opnametijd:</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>Videoformaat:</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>Vrije schijfruimte:</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>Informatie</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>Venster</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Schermvullend</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>Gebied</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>Videocodec</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>Frames</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Formaat</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>Beschikbaar</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>Niet beschikbaar</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Starten</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Stoppen</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Map</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>Cursor verbergen</translation>
+    </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>Audiocodec</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>Videomap</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>Aftellen</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>Hulp</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Omkeren</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Grijs</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Zwart-wit</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Camera</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Verticaal spiegelen</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Horizontaal spiegelen</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Vensterrand verwijderen</translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation>Aantal seconden voordat opname start</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>Standaardwaarden</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Venster verbergen</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Aantal seconden voordat opname start</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -601,42 +761,18 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>Afspelen</translation>
     </message>
     <message>
         <source>Pause</source>
-        <translation>Pauzeren</translation>
+        <translation>Onderbreken</translation>
     </message>
     <message>
         <source>Stop</source>
         <translation>Stoppen</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>Bestand openen</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Schermvullend</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>Vorig frame</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>Volgend frame</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>Dempen</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>Menu verplaatsen</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
