@@ -7,17 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>Kamera</translation>
-    </message>
-</context>
-<context>
-    <name>QvkCameraSettingsDialog</name>
-    <message>
-        <source>Camera settings</source>
-        <translation>Ustawienia kamery</translation>
+        <source>Select one or more devices</source>
+        <translation>Wybierz jedno lub wiele urządzeń</translation>
     </message>
 </context>
 <context>
@@ -57,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>Tryb okna</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>Tryb pełnoekranowy</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>Kamera</translation>
@@ -92,13 +77,6 @@
         <translation>Dialog</translation>
     </message>
 </context>
-<context>
-    <name>QvkDirectSoundController</name>
-    <message>
-        <source>Select one or more devices</source>
-        <translation>Wybierz jedno lub wiele urządzeń</translation>
-    </message>
-</context>
 <context>
     <name>QvkHelp</name>
     <message>
@@ -117,6 +95,17 @@
         <translation>Zainstaluj menedżer plików.</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Brak menedżera plików.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Zainstaluj menedżer plików.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -190,6 +179,14 @@
         <source>Donate</source>
         <translation>Darowizna</translation>
     </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Brak menedżera plików.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Zainstaluj menedżer plików.</translation>
+    </message>
 </context>
 <context>
     <name>QvkPulseAudioWatcher</name>
@@ -198,6 +195,13 @@
         <translation>Wybierz jedno lub wiele urządzeń</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Wybierz jedno lub wiele urządzeń</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -485,18 +489,6 @@
         <source>Gray</source>
         <translation>Szary</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+SHIFT+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+SHIFT+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+SHIFT+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>Odtwórz ostatnie nagranie</translation>
@@ -505,10 +497,6 @@
         <source>Open folder</source>
         <translation>Otwórz folder</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>CTRL+SHIFT+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>Zminimalizuj po rozpoczęniu nagrania</translation>
@@ -696,18 +684,6 @@
         <source>Stop</source>
         <translation>Stop</translation>
     </message>
-    <message>
-        <source>Pause</source>
-        <translation>Pauza</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Kontynuuj</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Odtwórz</translation>
-    </message>
     <message>
         <source>Folder</source>
         <translation>Folder</translation>
@@ -716,6 +692,66 @@
         <source>Do not record mouse cursor</source>
         <translation>Nie nagrywaj kursora myszy</translation>
     </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>Kodek audio</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>Zapisz nagranie w</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>Odliczanie</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>Pomoc</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Odwróć</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Szary</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Czarno-białe</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Odwróć pionowo</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Odwróć poziomo</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Usuń ramkę okna</translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation>Sekund do nagrania</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>Resetuj</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Ukryj to okno</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Sekundy oczekiwania przed rozpoczęciem nagrania</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
