@@ -7,17 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>Câmara</translation>
-    </message>
-</context>
-<context>
-    <name>QvkCameraSettingsDialog</name>
-    <message>
-        <source>Camera settings</source>
-        <translation>Configurações da câmara</translation>
+        <source>Select one or more devices</source>
+        <translation>Selecione um ou mais dispositivos</translation>
     </message>
 </context>
 <context>
@@ -57,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>Mudar para janela</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>Mudar para ecrã inteiro</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>Câmara</translation>
@@ -92,13 +77,6 @@
         <translation>Diálogo</translation>
     </message>
 </context>
-<context>
-    <name>QvkDirectSoundController</name>
-    <message>
-        <source>Select one or more devices</source>
-        <translation>Seleccione um ou mais dispositivos</translation>
-    </message>
-</context>
 <context>
     <name>QvkHelp</name>
     <message>
@@ -117,6 +95,17 @@
         <translation>Por favor, instale um gestor de ficheiros.</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Não foi encontrado um gestor de ficheiros.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Por favor, instale um gestor de ficheiros.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -190,6 +179,14 @@
         <source>Donate</source>
         <translation>Doar</translation>
     </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Não foi encontrado um gestor de ficheiros.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Por favor, instale um gestor de ficheiros.</translation>
+    </message>
 </context>
 <context>
     <name>QvkPulseAudioWatcher</name>
@@ -198,6 +195,13 @@
         <translation>Selecione um ou mais dispositivos</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Selecione um ou mais dispositivos</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -485,18 +489,6 @@
         <source>Gray</source>
         <translation>Cinzento</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+SHIFT+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+SHIFT+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+SHIFT+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>Reproduzir a última gravação</translation>
@@ -505,10 +497,6 @@
         <source>Open folder</source>
         <translation>Abrir pasta</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>CTRL+SHIFT+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>Minimizar quando a gravação Iniciar</translation>
@@ -696,18 +684,6 @@
         <source>Stop</source>
         <translation>Parar</translation>
     </message>
-    <message>
-        <source>Pause</source>
-        <translation>Pausa</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Continuar</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Reproduzir</translation>
-    </message>
     <message>
         <source>Folder</source>
         <translation>Pasta</translation>
@@ -716,6 +692,66 @@
         <source>Do not record mouse cursor</source>
         <translation>Não gravar o cursor do rato</translation>
     </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>Codec de áudio</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>Caminho do vídeo </translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>Contagem decrescente</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>Ajuda</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Inverter</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Cinzento</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Preto e branco</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Câmara</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Girar vertical</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Girar horizontal</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Remover a moldura da janela</translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation>Esperar em segundos antes de iniciar a gravar</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>Reiniciar</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Esconder esta janela</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Espera em segundos antes de gravar</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
