@@ -7,14 +7,38 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>Câmara</translation>
+        <source>Select one or more devices</source>
+        <translation>Selecione um ou mais dispositivos</translation>
     </message>
 </context>
 <context>
-    <name>QvkCameraWindow</name>
+    <name>QvkCameraSingle</name>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Eliminar a borda da janela</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Virar verticalmente</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Virar horizontalmente</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Inverter</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Cinza</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Preto e branco</translation>
+    </message>
     <message>
         <source>Switch to Window</source>
         <translation>Mudar para janela</translation>
@@ -24,6 +48,13 @@
         <translation>Mudar para ecrã inteiro</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraWindow</name>
+    <message>
+        <source>Camera</source>
+        <translation>Câmara</translation>
+    </message>
+</context>
 <context>
     <name>QvkCiscoFinishDialog</name>
     <message>
@@ -40,10 +71,10 @@
     </message>
 </context>
 <context>
-    <name>QvkDirectSoundController</name>
+    <name>QvkDirDialog</name>
     <message>
-        <source>Select one or more devices</source>
-        <translation>Selecione um ou mais dispositivos</translation>
+        <source>Dialog</source>
+        <translation>Diálogo</translation>
     </message>
 </context>
 <context>
@@ -64,6 +95,17 @@
         <translation>Por favor, instale um gestor de ficheiros.</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Não foi encontrado nenhum gestor de ficheiros.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Por favor, instale um gestor de ficheiros.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -93,16 +135,9 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Ecrã inteiro</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>Janela</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
+        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
         <translation>Não foi encontrado nenhum gestor de ficheiros.</translation>
     </message>
     <message>
@@ -126,6 +161,33 @@
         <translation>Faz uma doação</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>Código-fonte</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>Site</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>Traduções</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>Faz uma doação</translation>
+    </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Não foi encontrado nenhum gestor de ficheiros.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Por favor, instale um gestor de ficheiros.</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -133,6 +195,13 @@
         <translation>Selecione um ou mais dispositivos</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Selecione um ou mais dispositivos</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -147,6 +216,17 @@
         <translation>Área</translation>
     </message>
 </context>
+<context>
+    <name>QvkSnapshot</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Não foi encontrado nenhum gestor de ficheiros.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Por favor, instale um gestor de ficheiros.</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -209,6 +289,13 @@
         <translation>Ampliação</translation>
     </message>
 </context>
+<context>
+    <name>QvkWASAPIController</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Selecione um ou mais dispositivos</translation>
+    </message>
+</context>
 <context>
     <name>cameraSettingsDialog</name>
     <message>
@@ -298,10 +385,6 @@
         <source>Audiocodec</source>
         <translation>Codificador de áudio</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>Qualidade</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>Não gravar o cursor do rato</translation>
@@ -406,22 +489,6 @@
         <source>Gray</source>
         <translation>Cinza</translation>
     </message>
-    <message>
-        <source>Send Report</source>
-        <translation>Enviar relatório</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>Ctrl+Shift+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>Ctrl+Shift+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>Ctrl+Shift+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>Executar a última gravação</translation>
@@ -430,10 +497,6 @@
         <source>Open folder</source>
         <translation>Abrir pasta</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>Ctrl+Shift+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>Minimizado no início da gravação</translation>
@@ -458,10 +521,6 @@
         <source>Remove window frame</source>
         <translation>Eliminar a borda da janela</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>Faz uma doação</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>Reinicializar todas as configurações no próximo início</translation>
@@ -522,6 +581,177 @@
         <source>If it shows assigned but does not work, it is being used by another program.</source>
         <translation>Se é mostrado como atribuído mas não funciona, é porque está a ser usado por outro programa</translation>
     </message>
+    <message>
+        <source>Snapshot</source>
+        <translation>Instantâneo</translation>
+    </message>
+    <message>
+        <source>Imagepath</source>
+        <translation>Caminho da imagem</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Esconder esta janela</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Segundos para esperar antes de gravar</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>Janela</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Ecrã inteiro</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>Direitos de autor e licença das imagens</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Criar imagens e separadores</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Informação sobre Licença</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>LIGADO</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>DESLIGADO</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>Duração da gravação:</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>Tamanho do vídeo:</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>Espaço livre em disco:</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>Informação</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>Janela</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Ecrã inteiro</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>Área</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>Codificador de vídeo</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>Quadros de vídeo</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Formato</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>Disponível</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>Não disponível</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Começar</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Parar</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Pasta</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>Não gravar o cursor do rato</translation>
+    </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>Codificador de áudio</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>Caminho para ficheiro de vídeo</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>Contagem decrescente</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>Ajuda</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Inverter</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Cinza</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Preto e branco</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Câmara</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Virar verticalmente</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Virar horizontalmente</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Eliminar a borda da janela</translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation>Segundos para esperar antes de gravar</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>Reinicializar</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Esconder esta janela</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Segundos para esperar antes de gravar</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -531,42 +761,18 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>Executar</translation>
     </message>
     <message>
         <source>Pause</source>
-        <translation>Pausar</translation>
+        <translation>Pausa</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation>Terminar</translation>
-    </message>
-    <message>
-        <source>Open File</source>
-        <translation>Abrir ficheiro</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Ecrã completo</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>Quadro anterior</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>Quadro seguinte</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>Silenciar</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>Deslocar o menu</translation>
+        <translation>Parar</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
