@@ -7,17 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>Камера</translation>
-    </message>
-</context>
-<context>
-    <name>QvkCameraSettingsDialog</name>
-    <message>
-        <source>Camera settings</source>
-        <translation>Параметры камеры</translation>
+        <source>Select one or more devices</source>
+        <translation>ВыберитВыберите одно или несколько устройстве одно или несколько устройств</translation>
     </message>
 </context>
 <context>
@@ -57,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>Переключиться в режим окна</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>Переключиться в полноэкранный режим</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>Камера</translation>
@@ -92,13 +77,6 @@
         <translation>Диалоговое окно</translation>
     </message>
 </context>
-<context>
-    <name>QvkDirectSoundController</name>
-    <message>
-        <source>Select one or more devices</source>
-        <translation>Выберите одно или несколько устройств</translation>
-    </message>
-</context>
 <context>
     <name>QvkHelp</name>
     <message>
@@ -117,6 +95,17 @@
         <translation>Пожалуйста установите файловый менеджер.</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Файловый менеджер не найден.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Пожалуйста установите файловый менеджер.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -190,6 +179,14 @@
         <source>Donate</source>
         <translation>Пожертвовать</translation>
     </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Файловый менеджер не найден.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Пожалуйста установите файловый менеджер.</translation>
+    </message>
 </context>
 <context>
     <name>QvkPulseAudioWatcher</name>
@@ -198,6 +195,13 @@
         <translation>ВыберитВыберите одно или несколько устройстве одно или несколько устройств</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>ВыберитВыберите одно или несколько устройстве одно или несколько устройств</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -485,18 +489,6 @@
         <source>Gray</source>
         <translation>Чёрно-белое в оттенках серого</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+SHIFT+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+SHIFT+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+SHIFT+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>Воспроизвести последнюю запись</translation>
@@ -505,10 +497,6 @@
         <source>Open folder</source>
         <translation>Открыть папку</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>CTRL+SHIFT+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>Сворачивать окно перед началом записи</translation>
@@ -696,18 +684,6 @@
         <source>Stop</source>
         <translation>Остановить</translation>
     </message>
-    <message>
-        <source>Pause</source>
-        <translation>Приостановить</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Продолжить</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Воспроизвести</translation>
-    </message>
     <message>
         <source>Folder</source>
         <translation>Папка</translation>
@@ -716,6 +692,66 @@
         <source>Do not record mouse cursor</source>
         <translation>Не записывать указатель мыши</translation>
     </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>Звуковой кодек</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>Путь к видео:</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>Обратный отсчёт</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>Справка</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Инвертировать</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Чёрно-белое в оттенках серого</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Чёрно-белое двухцветное</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Камера</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Отразить по вертикали</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Отразить по горизонтали</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Убрать рамку окна</translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation>Секунд до начала записи</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>Сбросить</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Скрыть это окно</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Секунды ожидания перед записью</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
