@@ -7,17 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>Kamera</translation>
-    </message>
-</context>
-<context>
-    <name>QvkCameraSettingsDialog</name>
-    <message>
-        <source>Camera settings</source>
-        <translation>Nastavenia kamery</translation>
+        <source>Select one or more devices</source>
+        <translation>Vyberte jedno alebo viac zariadení</translation>
     </message>
 </context>
 <context>
@@ -57,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>Zobraziť v okne</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>Zobraziť na celú obrazovku</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>Kamera</translation>
@@ -78,11 +63,11 @@
     </message>
     <message>
         <source>Close this window and start vokoscreenNG again.</source>
-        <translation>Zatvorte okno a spustite vokoscreenNG opäť.</translation>
+        <translation>Zatvorte okno a znovu spustite vokoscreenNG</translation>
     </message>
     <message>
         <source>Have fun with vokoscreenNG</source>
-        <translation>Zabávajte sa s vokoscreenNG</translation>
+        <translation>Veľa zábavy s vokoscreenNG</translation>
     </message>
 </context>
 <context>
@@ -92,13 +77,6 @@
         <translation>Dialóg</translation>
     </message>
 </context>
-<context>
-    <name>QvkDirectSoundController</name>
-    <message>
-        <source>Select one or more devices</source>
-        <translation>Vyberte jedno alebo viac zariadení</translation>
-    </message>
-</context>
 <context>
     <name>QvkHelp</name>
     <message>
@@ -110,11 +88,22 @@
     <name>QvkImageFromTabs</name>
     <message>
         <source>No filemanager found.</source>
-        <translation>Nenašiel sa žiadny súborový manažér.</translation>
+        <translation>Nenašiel sa správca súborov.</translation>
     </message>
     <message>
         <source>Please install a filemanager.</source>
-        <translation>Inštalujte súborový manažér.</translation>
+        <translation>Prosím, nainštalujte správcu súborov.</translation>
+    </message>
+</context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Nenašiel sa správca súborov.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Prosím, nainštalujte správcu súborov.</translation>
     </message>
 </context>
 <context>
@@ -149,11 +138,11 @@
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
-        <translation>Nenašiel sa žiadny súborový manažér.</translation>
+        <translation>Nenašiel sa správca súborov.</translation>
     </message>
     <message>
         <source>Please install a filemanager.</source>
-        <translation>Inštalujte súborový manažér.</translation>
+        <translation>Prosím, nainštalujte správcu súborov.</translation>
     </message>
     <message>
         <source>Sourcecode</source>
@@ -190,6 +179,14 @@
         <source>Donate</source>
         <translation>Podporiť</translation>
     </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Nenašiel sa správca súborov.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Prosím, nainštalujte správcu súborov.</translation>
+    </message>
 </context>
 <context>
     <name>QvkPulseAudioWatcher</name>
@@ -198,6 +195,13 @@
         <translation>Vyberte jedno alebo viac zariadení</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Vyberte jedno alebo viac zariadení</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -216,11 +220,11 @@
     <name>QvkSnapshot</name>
     <message>
         <source>No filemanager found.</source>
-        <translation>Nenašiel sa žiadny súborový manažér.</translation>
+        <translation>Nenašiel sa správca súborov.</translation>
     </message>
     <message>
         <source>Please install a filemanager.</source>
-        <translation>Inštalujte súborový manažér.</translation>
+        <translation>Prosím, nainštalujte správcu súborov.</translation>
     </message>
 </context>
 <context>
@@ -371,7 +375,7 @@
     </message>
     <message>
         <source>Videocodec</source>
-        <translation>Kódek video</translation>
+        <translation>Videokodek</translation>
     </message>
     <message>
         <source>Format</source>
@@ -379,7 +383,7 @@
     </message>
     <message>
         <source>Audiocodec</source>
-        <translation>Zvukový kódek</translation>
+        <translation>Audiokodek</translation>
     </message>
     <message>
         <source>Do not record mouse cursor</source>
@@ -471,7 +475,7 @@
     </message>
     <message>
         <source>Folder</source>
-        <translation>Priečinok - adresár</translation>
+        <translation>Priečinok</translation>
     </message>
     <message>
         <source>Camera</source>
@@ -485,29 +489,13 @@
         <source>Gray</source>
         <translation>Stupne sivej</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+SHIFT+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+SHIFT+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+SHIFT+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>Prehrať poslednú nahrávku</translation>
     </message>
     <message>
         <source>Open folder</source>
-        <translation>Otvoriť adresár - priečinok</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>CTRL+SHIFT+F8</translation>
+        <translation>Otvoriť priečinok</translation>
     </message>
     <message>
         <source>Minimized when recording starts</source>
@@ -539,7 +527,7 @@
     </message>
     <message>
         <source>Copyright and license from pictures</source>
-        <translation>Copyright a licencie obrázkov</translation>
+        <translation>Autorské práva a licencie obrázkov</translation>
     </message>
     <message>
         <source>Megabyte</source>
@@ -579,7 +567,7 @@
     </message>
     <message>
         <source>Global keyboard shortcuts</source>
-        <translation>Globálne klávesnicove skratky</translation>
+        <translation>Globálne klávesové skratky</translation>
     </message>
     <message>
         <source>Assigned shortcut keys.</source>
@@ -595,7 +583,7 @@
     </message>
     <message>
         <source>Snapshot</source>
-        <translation>Snímok obrazovky</translation>
+        <translation>Snímka obrazovky</translation>
     </message>
     <message>
         <source>Imagepath</source>
@@ -622,7 +610,7 @@
     <name>formMainWindow_wl</name>
     <message>
         <source>Copyright and license from pictures</source>
-        <translation>Copyright a licencie obrázkov</translation>
+        <translation>Autorské práva a licencie obrázkov</translation>
     </message>
     <message>
         <source>Create images of tabs </source>
@@ -670,7 +658,7 @@
     </message>
     <message>
         <source>Videocodec</source>
-        <translation>Kódek video</translation>
+        <translation>Videokodek</translation>
     </message>
     <message>
         <source>Frames</source>
@@ -696,32 +684,80 @@
         <source>Stop</source>
         <translation>Stop</translation>
     </message>
-    <message>
-        <source>Pause</source>
-        <translation>Pauza</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Pokračovať</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Prehrať</translation>
-    </message>
     <message>
         <source>Folder</source>
-        <translation>Priečinok - adresár</translation>
+        <translation>Priečinok</translation>
     </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>Nenahrávať kurzor myši</translation>
     </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>Audiokodek</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>Cesta k videu</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>Odpočítavanie</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>Pomocník</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Invertovať</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Stupne sivej</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Dvojfarebné, čierna a biela </translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Prevrátiť vertikálne</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Prevrátiť horizontálne</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Odstrániť orámovanie okna</translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation>Čakanie v sekundách pred nahrávaním</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>Resetovanie</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Schovať okno</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Sekundy pred nahrávaním</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
     <message>
         <source>Copyright and license from pictures</source>
-        <translation>Copyright a licencie obrázkov</translation>
+        <translation>Autorské práva a licencie obrázkov</translation>
     </message>
 </context>
 <context>
