@@ -7,14 +7,38 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>Kamera</translation>
+        <source>Select one or more devices</source>
+        <translation>Izbor ene ali več naprav</translation>
     </message>
 </context>
 <context>
-    <name>QvkCameraWindow</name>
+    <name>QvkCameraSingle</name>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Odstrani okvir okna</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Zrcali navpično</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Zrcali vodoravno</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Obrni</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Sivo</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Črnobelo</translation>
+    </message>
     <message>
         <source>Switch to Window</source>
         <translation>Preklopi na okno</translation>
@@ -25,25 +49,32 @@
     </message>
 </context>
 <context>
-    <name>QvkCiscoFinishDialog</name>
+    <name>QvkCameraWindow</name>
     <message>
-        <source>The setup was successful.</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Close this window and start vokoscreenNG again.</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Have fun with vokoscreenNG</source>
-        <translation type="unfinished"/>
+        <source>Camera</source>
+        <translation>Kamera</translation>
     </message>
 </context>
 <context>
-    <name>QvkDirectSoundController</name>
+    <name>QvkCiscoFinishDialog</name>
     <message>
-        <source>Select one or more devices</source>
-        <translation>Izbor ene ali več naprav</translation>
+        <source>The setup was successful.</source>
+        <translation>Namestitev je bila uspešna.</translation>
+    </message>
+    <message>
+        <source>Close this window and start vokoscreenNG again.</source>
+        <translation>Zapri to okno in ponovno zaženi vokoscreenNG.</translation>
+    </message>
+    <message>
+        <source>Have fun with vokoscreenNG</source>
+        <translation>Zabavaj se z vokoscreenNG</translation>
+    </message>
+</context>
+<context>
+    <name>QvkDirDialog</name>
+    <message>
+        <source>Dialog</source>
+        <translation>Pogovorno okno</translation>
     </message>
 </context>
 <context>
@@ -64,6 +95,17 @@
         <translation>Program za urejanje datotek je treba namestiti.</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Ni najdenega upravljalnika datotek.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Program za urejanje datotek je treba namestiti.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -93,16 +135,9 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Celozaslonski način</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>Okno</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
+        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
         <translation>Ni najdenega upravljalnika datotek.</translation>
     </message>
     <message>
@@ -126,6 +161,33 @@
         <translation>Doniraj</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>Izvorna koda</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>Spletna stran</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>Prevodi</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>Doniraj</translation>
+    </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Ni najdenega upravljalnika datotek.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Program za urejanje datotek je treba namestiti.</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -133,6 +195,13 @@
         <translation>Izbor ene ali več naprav</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Izbor ene ali več naprav</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -147,6 +216,17 @@
         <translation>Območje</translation>
     </message>
 </context>
+<context>
+    <name>QvkSnapshot</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Ni najdenega upravljalnika datotek.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Program za urejanje datotek je treba namestiti.</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -209,6 +289,13 @@
         <translation>Povečava</translation>
     </message>
 </context>
+<context>
+    <name>QvkWASAPIController</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Izbor ene ali več naprav</translation>
+    </message>
+</context>
 <context>
     <name>cameraSettingsDialog</name>
     <message>
@@ -298,10 +385,6 @@
         <source>Audiocodec</source>
         <translation>Zvokovni kodek</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>Kakovost</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>Ne snemaj kazalke miške</translation>
@@ -406,22 +489,6 @@
         <source>Gray</source>
         <translation>Sivo</translation>
     </message>
-    <message>
-        <source>Send Report</source>
-        <translation>Pošlji poročilo</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+SHIFT+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+SHIFT+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+SHIFT+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>Predvajaj zadnji posnetek</translation>
@@ -430,10 +497,6 @@
         <source>Open folder</source>
         <translation>Odpri mapo</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>CTRL+SHIFT+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>Pomanjšaj, ko se snemanje začne</translation>
@@ -458,10 +521,6 @@
         <source>Remove window frame</source>
         <translation>Odstrani okvir okna</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>Doniraj</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>Ponastavi nastavitve ob naslednjem zagonu</translation>
@@ -488,39 +547,210 @@
     </message>
     <message>
         <source>Automatically</source>
-        <translation type="unfinished"/>
+        <translation>Avtomatsko</translation>
     </message>
     <message>
         <source>Create images of tabs </source>
-        <translation type="unfinished"/>
+        <translation>Ustvari slike zavihkov</translation>
     </message>
     <message>
         <source>License information</source>
-        <translation type="unfinished"/>
+        <translation>Licenčne informacije</translation>
     </message>
     <message>
         <source>ON</source>
-        <translation type="unfinished"/>
+        <translation>VKLJUČENO</translation>
     </message>
     <message>
         <source>OFF</source>
-        <translation type="unfinished"/>
+        <translation>IZKLJUČENO</translation>
     </message>
     <message>
         <source>Global keyboard shortcuts</source>
-        <translation type="unfinished"/>
+        <translation>Globalne bližnjice tipkovnice</translation>
     </message>
     <message>
         <source>Assigned shortcut keys.</source>
-        <translation type="unfinished"/>
+        <translation>Dodeljene bližnjice tipk.</translation>
     </message>
     <message>
         <source>Keyboard shortcut not assigned or assigned more than once.</source>
-        <translation type="unfinished"/>
+        <translation>Bližnjica tipkovnice ni dodeljena ali pa je dodeljena več kot enkrat.</translation>
     </message>
     <message>
         <source>If it shows assigned but does not work, it is being used by another program.</source>
-        <translation type="unfinished"/>
+        <translation>Če je prikazana dodeljena, ampak ne deluje, je v uporabi od drugega programa</translation>
+    </message>
+    <message>
+        <source>Snapshot</source>
+        <translation>Posnetek</translation>
+    </message>
+    <message>
+        <source>Imagepath</source>
+        <translation>Pot datoteke</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Skrij to okno</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Čakanje v sekundah pred snemanjem</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>Okno</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Celozaslonski način</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>Avtorske pravice in dovoljenja slik</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Ustvari slike zavihkov</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Licenčne informacije</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>VKLJUČENO</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>IZKLJUČENO</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>Čas snemanja</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>Velikost videa:</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>Prostor na disku:</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>Podrobnosti</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>Okno</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Celozaslonski način</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>Območje</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>Video kodek</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>Sličice</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Zapis</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>Na voljo</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>Ni na voljo</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Začni</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Zaustavi</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Mapa</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>Ne snemaj kazalke miške</translation>
+    </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>Zvokovni kodek</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>Pot do videa</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>Odštevalnik</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>Pomoč</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Obrni</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Sivo</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Črnobelo</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Zrcali navpično</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Zrcali vodoravno</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Odstrani okvir okna</translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation>Čas čakanja pred začetkom snemanja</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>Ponastavi</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Skrij to okno</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Čakanje v sekundah pred snemanjem</translation>
     </message>
 </context>
 <context>
@@ -531,7 +761,7 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>Predvajaj</translation>
@@ -544,29 +774,5 @@
         <source>Stop</source>
         <translation>Zaustavi</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>Odpri datoteko</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Celozaslonski način</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>Predhodna sličica</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>Naslednja sličica</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>Utišaj</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>Premakni meni</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
