@@ -7,17 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>Kamera</translation>
-    </message>
-</context>
-<context>
-    <name>QvkCameraSettingsDialog</name>
-    <message>
-        <source>Camera settings</source>
-        <translation>Подешавања камере</translation>
+        <source>Select one or more devices</source>
+        <translation>Означи један или више уређаја</translation>
     </message>
 </context>
 <context>
@@ -57,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>Промени на прозор</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>Промени на цео екран</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>Kamera</translation>
@@ -92,13 +77,6 @@
         <translation>Дијалог</translation>
     </message>
 </context>
-<context>
-    <name>QvkDirectSoundController</name>
-    <message>
-        <source>Select one or more devices</source>
-        <translation>Означи један или више уређаја</translation>
-    </message>
-</context>
 <context>
     <name>QvkHelp</name>
     <message>
@@ -117,6 +95,17 @@
         <translation>Молим вас инсталирајте претраживач датотека</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Претраживач датотека није пронађен</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Молим вас инсталирајте претраживач датотека</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -190,6 +179,14 @@
         <source>Donate</source>
         <translation>Донирај</translation>
     </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Претраживач датотека није пронађен</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Молим вас инсталирајте претраживач датотека</translation>
+    </message>
 </context>
 <context>
     <name>QvkPulseAudioWatcher</name>
@@ -198,6 +195,13 @@
         <translation>Означи један или више уређаја</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Означи један или више уређаја</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -485,18 +489,6 @@
         <source>Gray</source>
         <translation>Сиво</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+SHIFT+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+SHIFT+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+SHIFT+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>Пусти задњи снимак</translation>
@@ -505,10 +497,6 @@
         <source>Open folder</source>
         <translation>Отвори директоријум</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>CTRL+SHIFT+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>Vokoscreen минимизиран кад снимање почне</translation>
@@ -696,18 +684,6 @@
         <source>Stop</source>
         <translation>Стоп</translation>
     </message>
-    <message>
-        <source>Pause</source>
-        <translation>Пауза</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Настави</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Почни</translation>
-    </message>
     <message>
         <source>Folder</source>
         <translation>Фасцикла</translation>
@@ -716,6 +692,66 @@
         <source>Do not record mouse cursor</source>
         <translation>Немој снимати стрелицу</translation>
     </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>Аудио кодек</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>Видео пут</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>Одбројавање</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>Помоћ</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Изокрени</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Сиво</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Црно-бело</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Окрени вертикално</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Окрени хоризонтално</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Уклони оквир прозора</translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation>Одлагање снимања у секундама</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>Поново намести</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Сакриј овај прозор</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Секунде пре почетка снимања</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
