@@ -7,17 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>Kamera</translation>
-    </message>
-</context>
-<context>
-    <name>QvkCameraSettingsDialog</name>
-    <message>
-        <source>Camera settings</source>
-        <translation>Kamerainställningar</translation>
+        <source>Select one or more devices</source>
+        <translation>Välj en eller flera enheter</translation>
     </message>
 </context>
 <context>
@@ -57,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>Växla till fönsterläge</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>Växla till helskärmsläge</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>Kamera</translation>
@@ -92,13 +77,6 @@
         <translation>Dialog</translation>
     </message>
 </context>
-<context>
-    <name>QvkDirectSoundController</name>
-    <message>
-        <source>Select one or more devices</source>
-        <translation>Välj en eller flera enheter</translation>
-    </message>
-</context>
 <context>
     <name>QvkHelp</name>
     <message>
@@ -117,6 +95,17 @@
         <translation>Installera en filhanterare.</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Ingen filhanterare hittades.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Installera en filhanterare.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -190,6 +179,14 @@
         <source>Donate</source>
         <translation>Donera</translation>
     </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Ingen filhanterare hittades.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Installera en filhanterare.</translation>
+    </message>
 </context>
 <context>
     <name>QvkPulseAudioWatcher</name>
@@ -198,6 +195,13 @@
         <translation>Välj en eller flera enheter</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Välj en eller flera enheter</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -485,18 +489,6 @@
         <source>Gray</source>
         <translation>Grå</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+SHIFT+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+SHIFT+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+SHIFT+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>Spela upp senaste inspelning</translation>
@@ -505,10 +497,6 @@
         <source>Open folder</source>
         <translation>Öppna mapp</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>CTRL+SHIFT+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>Minimerad när inspelning startar</translation>
@@ -696,18 +684,6 @@
         <source>Stop</source>
         <translation>Stoppa</translation>
     </message>
-    <message>
-        <source>Pause</source>
-        <translation>Pausa</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Fortsätt</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Spela upp</translation>
-    </message>
     <message>
         <source>Folder</source>
         <translation>Mapp</translation>
@@ -716,6 +692,66 @@
         <source>Do not record mouse cursor</source>
         <translation>Spela inte in muspekaren</translation>
     </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>Ljudkodek</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>Videosökväg</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>Nedräkning</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>Hjälp</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Invertera</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Grå</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Svartvit</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Vänd vertikalt</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Vänd horisontellt</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Ta bort fönsterram</translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation>Vänta x sekunder före inspelningsstart</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>Återställ</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Dölj det här fönstret</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Sekunders väntetid före inspelning</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
