@@ -7,10 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>Kamera</translation>
+        <source>Select one or more devices</source>
+        <translation>Välj en eller flera enheter</translation>
     </message>
 </context>
 <context>
@@ -50,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>Växla till fönsterläge</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>Växla till helskärmsläge</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>Kamera</translation>
@@ -79,10 +71,10 @@
     </message>
 </context>
 <context>
-    <name>QvkDirectSoundController</name>
+    <name>QvkDirDialog</name>
     <message>
-        <source>Select one or more devices</source>
-        <translation>Välj en eller flera enheter</translation>
+        <source>Dialog</source>
+        <translation>Dialog</translation>
     </message>
 </context>
 <context>
@@ -103,6 +95,17 @@
         <translation>Installera en filhanterare.</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Ingen filhanterare hittades.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Installera en filhanterare.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -132,14 +135,6 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Helskärm</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>Fönster</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
@@ -166,6 +161,33 @@
         <translation>Donera</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>Källkod</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>Hemsida</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>Översättningar</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>Donera</translation>
+    </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Ingen filhanterare hittades.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Installera en filhanterare.</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -173,6 +195,13 @@
         <translation>Välj en eller flera enheter</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Välj en eller flera enheter</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -356,10 +385,6 @@
         <source>Audiocodec</source>
         <translation>Ljudkodek</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>Kvalitet</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>Spela inte in muspekaren</translation>
@@ -464,18 +489,6 @@
         <source>Gray</source>
         <translation>Grå</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+SHIFT+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+SHIFT+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+SHIFT+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>Spela upp senaste inspelning</translation>
@@ -484,10 +497,6 @@
         <source>Open folder</source>
         <translation>Öppna mapp</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>CTRL+SHIFT+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>Minimerad när inspelning startar</translation>
@@ -512,10 +521,6 @@
         <source>Remove window frame</source>
         <translation>Ta bort fönsterram</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>Donera</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>Återställ alla inställningar vid nästa programstart</translation>
@@ -592,6 +597,161 @@
         <source>Seconds wait before recording</source>
         <translation>Sekunders väntetid före inspelning</translation>
     </message>
+    <message>
+        <source>Window</source>
+        <translation>Fönster</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Helskärm</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>Copyright och licens från bilder</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Skapa bilder av flikar</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Licensinformation</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>PÅ</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>AV</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>Inspelningstid:</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>Videostorlek:</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>Ledigt diskutrymme:</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>Information</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>Fönster</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Helskärm</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>Område</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>Videokodek</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>Bildrutor</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Format</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>Tillgänglig</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>Inte tillgänglig</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Starta</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Stoppa</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Mapp</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>Spela inte in muspekaren</translation>
+    </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>Ljudkodek</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>Videosökväg</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>Nedräkning</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>Hjälp</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Invertera</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Grå</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Svartvit</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Vänd vertikalt</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Vänd horisontellt</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Ta bort fönsterram</translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation>Vänta x sekunder före inspelningsstart</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>Återställ</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Dölj det här fönstret</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Sekunders väntetid före inspelning</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -601,7 +761,7 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>Spela upp</translation>
@@ -614,29 +774,5 @@
         <source>Stop</source>
         <translation>Stoppa</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>Öppna fil</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Helskärm</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>Föregående bildruta</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>Nästa bildruta</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>Tyst</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>Flytta menyn</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
