@@ -7,17 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>Камера</translation>
-    </message>
-</context>
-<context>
-    <name>QvkCameraSettingsDialog</name>
-    <message>
-        <source>Camera settings</source>
-        <translation>Налаштування камери</translation>
+        <source>Select one or more devices</source>
+        <translation>Оберіть один або декілька пристроїв</translation>
     </message>
 </context>
 <context>
@@ -57,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>Перемикнутися на режим вікна</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>Перемикнутися на повний екран</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>Камера</translation>
@@ -92,13 +77,6 @@
         <translation>Діалогове вікно</translation>
     </message>
 </context>
-<context>
-    <name>QvkDirectSoundController</name>
-    <message>
-        <source>Select one or more devices</source>
-        <translation>Оберіть один або декілька пристроїв</translation>
-    </message>
-</context>
 <context>
     <name>QvkHelp</name>
     <message>
@@ -117,6 +95,17 @@
         <translation>Будь ласка, встановіть файловий менеджер.</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Не знайдено файлового менеджера</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Будь ласка, встановіть файловий менеджер.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -190,6 +179,14 @@
         <source>Donate</source>
         <translation>Зробити внесок</translation>
     </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Не знайдено файлового менеджера</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Будь ласка, встановіть файловий менеджер.</translation>
+    </message>
 </context>
 <context>
     <name>QvkPulseAudioWatcher</name>
@@ -198,6 +195,13 @@
         <translation>Оберіть один або декілька пристроїв</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Оберіть один або декілька пристроїв</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -485,18 +489,6 @@
         <source>Gray</source>
         <translation>Сірий</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+SHIFT+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+SHIFT+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+SHIFT+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>Відтворити останній запис</translation>
@@ -505,10 +497,6 @@
         <source>Open folder</source>
         <translation>Відкрити теку</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>CTRL+SHIFT+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>Згортати вікно при початку запису</translation>
@@ -696,18 +684,6 @@
         <source>Stop</source>
         <translation>Зупинити</translation>
     </message>
-    <message>
-        <source>Pause</source>
-        <translation>Призупинити</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>Продовжити</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Програти</translation>
-    </message>
     <message>
         <source>Folder</source>
         <translation>Тека</translation>
@@ -716,6 +692,66 @@
         <source>Do not record mouse cursor</source>
         <translation>Не записувати вказівник миші</translation>
     </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>Авдіокодек</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>Зберегти до теки</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>Зворотній відлік</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>Допомога</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Перевернути</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Сірий</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>У відтінках сірого</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Камера</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Показати вертикально</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Показати горизонтально</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Прибрати рамку вікна</translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation>Зачекати секунд перед початком запису</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>Скинути</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Згорнути це вікно</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Зачекати секунду перед записуванням</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
