@@ -7,17 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>摄像头</translation>
-    </message>
-</context>
-<context>
-    <name>QvkCameraSettingsDialog</name>
-    <message>
-        <source>Camera settings</source>
-        <translation>摄像头设置</translation>
+        <source>Select one or more devices</source>
+        <translation>选取一个或多个设备</translation>
     </message>
 </context>
 <context>
@@ -57,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>切换至窗口模式</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>切换至全屏</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>摄像头</translation>
@@ -92,13 +77,6 @@
         <translation>对话框</translation>
     </message>
 </context>
-<context>
-    <name>QvkDirectSoundController</name>
-    <message>
-        <source>Select one or more devices</source>
-        <translation>选取一个或多个设备</translation>
-    </message>
-</context>
 <context>
     <name>QvkHelp</name>
     <message>
@@ -117,6 +95,17 @@
         <translation>请安装一个文件管理器。</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>未发现文件管理器</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>请安装一个文件管理器。</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -190,6 +179,14 @@
         <source>Donate</source>
         <translation>捐赠</translation>
     </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>未发现文件管理器</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>请安装一个文件管理器。</translation>
+    </message>
 </context>
 <context>
     <name>QvkPulseAudioWatcher</name>
@@ -198,6 +195,13 @@
         <translation>选取一个或多个设备</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>选取一个或多个设备</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -485,18 +489,6 @@
         <source>Gray</source>
         <translation>灰度</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+SHIFT+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+SHIFT+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+SHIFT+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>播放最后一次的录制</translation>
@@ -505,10 +497,6 @@
         <source>Open folder</source>
         <translation>打开文件夹</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>CTRL+SHIFT+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>当录制开始时最小化</translation>
@@ -696,18 +684,6 @@
         <source>Stop</source>
         <translation>停止</translation>
     </message>
-    <message>
-        <source>Pause</source>
-        <translation>暂停</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>继续</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>播放</translation>
-    </message>
     <message>
         <source>Folder</source>
         <translation>文件夹</translation>
@@ -716,6 +692,66 @@
         <source>Do not record mouse cursor</source>
         <translation>不要录制鼠标</translation>
     </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>音频编码</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>视频路径</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>倒计时</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>帮助</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>翻转</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>灰度</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>黑白</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>摄像头</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>纵向翻转</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>横向翻转</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>移除窗口边框</translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation>开始录制前等待秒数：</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>重置</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>隐藏窗口</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>开始录制前请等待数秒</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
