@@ -7,17 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>攝影機</translation>
-    </message>
-</context>
-<context>
-    <name>QvkCameraSettingsDialog</name>
-    <message>
-        <source>Camera settings</source>
-        <translation>攝影機設定</translation>
+        <source>Select one or more devices</source>
+        <translation>選取一個或多個裝置</translation>
     </message>
 </context>
 <context>
@@ -57,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>切換至視窗</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>切換至全螢幕</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>攝影機</translation>
@@ -92,13 +77,6 @@
         <translation>對話匣</translation>
     </message>
 </context>
-<context>
-    <name>QvkDirectSoundController</name>
-    <message>
-        <source>Select one or more devices</source>
-        <translation>選取一個或多個裝置</translation>
-    </message>
-</context>
 <context>
     <name>QvkHelp</name>
     <message>
@@ -117,6 +95,17 @@
         <translation>請安裝檔案管理員程式</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>找不到檔案管理員程式</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>請安裝檔案管理員程式</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -190,6 +179,14 @@
         <source>Donate</source>
         <translation>捐款支持</translation>
     </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>找不到檔案管理員程式</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>請安裝檔案管理員程式</translation>
+    </message>
 </context>
 <context>
     <name>QvkPulseAudioWatcher</name>
@@ -198,6 +195,13 @@
         <translation>選取一個或多個裝置</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>選取一個或多個裝置</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -485,18 +489,6 @@
         <source>Gray</source>
         <translation>灰色</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+SHIFT+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+SHIFT+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+SHIFT+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>播放上一條影片</translation>
@@ -505,10 +497,6 @@
         <source>Open folder</source>
         <translation>開啟資料夾</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>CTRL+SHIFT+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>開始錄製時最小化</translation>
@@ -696,18 +684,6 @@
         <source>Stop</source>
         <translation>停止</translation>
     </message>
-    <message>
-        <source>Pause</source>
-        <translation>暫停</translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation>繼續</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>播放</translation>
-    </message>
     <message>
         <source>Folder</source>
         <translation>資料夾</translation>
@@ -716,6 +692,66 @@
         <source>Do not record mouse cursor</source>
         <translation>不要錄製滑鼠游標</translation>
     </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>音訊編碼</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>影片路徑</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>倒數計時</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>求助</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>色彩反轉</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>灰色</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>黑白</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>攝影機</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>垂直翻轉</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>水平翻轉</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>移除視窗外框</translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation>開始錄製前等待秒數</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>重設</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>隱藏這個視窗</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>開始錄製前等待之秒數</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
