@@ -24,18 +24,19 @@
 #define QVKLICENSES_H
 
 #include "ui_licenses.h"
-#include "ui_formMainWindow.h"
 
 #include <QWidget>
 #include <QDebug>
 
+#include <QPushButton> // neu
+
 class QvkLicenses: public QWidget
 { 
     Q_OBJECT
 public:
-    QvkLicenses(Ui_formMainWindow *ui_mainwindow );
+    QvkLicenses( QPushButton *pushButton );
     virtual ~QvkLicenses();
-
+    Ui_license *ui;
 
 public slots:
 
@@ -50,7 +51,6 @@ protected:
 
 
 private:
-    Ui_license *ui;
     int readLicences(QString path , int row);
 
 };
