@@ -32,18 +32,16 @@ class QvkLogController : public QObject
 public:
     QvkLogController();
     virtual ~QvkLogController();
-    QString get_logPath();
+    QString get_log_filePath();
 
 
 public slots:
 
 
 signals:
-    void signal_newLogText( QString value );
 
 
 private slots:
-    void slot_addTextToGuiLog( QString value );
 
 
 private:
