@@ -38,7 +38,7 @@ QvkMagnifier::QvkMagnifier()
     slot_magnifier200x200();
 
     resize( 2 * distanceX * factor, 2 * distanceY * factor );
-#ifdef Q_OS_LINUX
+#ifdef Q_OS_UNIX
     setWindowFlags( Qt::X11BypassWindowManagerHint | Qt::WindowStaysOnTopHint );
 #endif
 #ifdef Q_OS_WIN
@@ -58,13 +58,13 @@ QvkMagnifier::~QvkMagnifier()
 {
 }
 
-
+/*
 void QvkMagnifier::slot_setMagnifierChangedSize(int value )
 {
     factor = value;
     resize( 2 * distanceX * factor, 2 * distanceY * factor );
 }
-
+*/
 
 void QvkMagnifier::slot_magnifierShow( bool value )
 {
@@ -463,7 +463,7 @@ void QvkMagnifier::slot_mytimer()
                     return;
         }
 
-        QPixmap painterPixmap( pixmap.width() * factor, pixmap.height() * factor );
+        QPixmap painterPixmap( width(), height() );
         painterPixmap.fill( Qt::transparent );
 
         QPainter painter;
@@ -477,7 +477,7 @@ void QvkMagnifier::slot_mytimer()
                     painter.setClipPath( path );
         }
 
-        QPixmap pix = pixmap.scaled( painterPixmap.width(), painterPixmap.height(), Qt::IgnoreAspectRatio, Qt::SmoothTransformation );
+        QPixmap pix = pixmap.scaled( pixmap.width() * factor, pixmap.height() * factor, Qt::IgnoreAspectRatio, Qt::SmoothTransformation );
         painter.drawPixmap( QPoint( 0, 0 ), pix );
 
         QPen pen;
@@ -486,6 +486,11 @@ void QvkMagnifier::slot_mytimer()
         painter.setPen( pen );
         if ( ( isToolButtonElipse == true ) or ( isToolButtonCircle == true ) ) {
                     painter.drawEllipse( 0, 0, width(), height() );
+                    /*                    qDebug() << "pixmap:" << pixmap.width() << pixmap.height() \
+                             << "PainterPixmap:" << painterPixmap.width() << painterPixmap.height() \
+                             << "pix:" << pix.width() << pix.height()
+                             << "Widget:" << width() << height();
+*/
         } else {
                     painter.drawRect( 0, 0, width(), height() );
         }
@@ -494,7 +499,7 @@ void QvkMagnifier::slot_mytimer()
         setPixmap( painterPixmap );
         setMagnifier();
 
-#ifdef Q_OS_LINUX
+#ifdef Q_OS_UNIX
         setMask( painterPixmap.mask() );
 #endif
 
