@@ -20,10 +20,18 @@
  * --End_License--
  */
 
+#include <QTranslator>
+#include <QLibraryInfo>
+#include <QLoggingCategory>
+#include <QStyleFactory>
+#include <QSettings>
+#include <QFile>
+
 #include "mainwindow.h"
 #include "global.h"
+#include "QvkLogController.h"
 
-#ifdef Q_OS_LINUX
+#ifdef Q_OS_UNIX
 #include "mainWindow_wl.h"
 #include "QvkWaylandRoutines.h"
 #endif
@@ -32,50 +40,27 @@
 #include "QvkSettings.h"
 #endif
 
-#include <QTranslator>
-#include <QLibraryInfo>
-#include <QLoggingCategory>
-#include <QStyleFactory>
-#include <QSettings>
-
 #include <gst/gst.h>
 
 int main(int argc, char *argv[])
 {
     QLoggingCategory::defaultCategory()->setEnabled( QtDebugMsg, true );
-
-    QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     QApplication::setStyle( QStyleFactory::create( "Fusion" ) );
-
     QApplication app(argc, argv);
 
     QString help;
-    help.append( "\n" );
-    help.append( "Usage: " + global::name + " [Option] [File or URL]" + "\n" );
-    help.append( "\n" );
-    help.append( "Options: \n" );
     help.append( "  -h or --help        Print this message\n" );
     help.append( "  -v or --version     Print version \n" );
     help.append( "\n" );
-    help.append( "File or Url:\n" );
-    help.append( "  Play a video\n" );
-    help.append( "    Example file:\n" );
-    help.append( "      vokoscreenNG /path/video\n" );
-    help.append( "\n" );
-    help.append( "    Example URL:\n");
-    help.append( "      vokoscreenNG http://www.rapconverter.com/SampleDownload/Sample320.mp4\n");
-    help.append( "      vokoscreenNG http://distribution.bbb3d.renderfarming.net/video/mp4/bbb_sunflower_1080p_60fps_normal.mp4" );
-    help.append( "\n" );
-
     QStringList arguments = QApplication::instance()->arguments();
     if ( !arguments.empty() and ( arguments.count() == 2 ) )
     {
         QStringList arguments = QApplication::instance()->arguments();
+        help:
         if ( ( arguments.at(1) == "--help" ) or
              ( arguments.at(1) == "-h"     ) )
         {
-            qDebug().resetFormat().noquote() << help;
+            qDebug().noquote() << help;
             return 0;
         }
 
@@ -83,30 +68,17 @@ int main(int argc, char *argv[])
         {
             qDebug().noquote() << global::name << global::version;
             return 0;
+        } {
+            arguments.clear();
+            arguments.append( " ");
+            arguments.append( "--help" );
+            goto help;
         }
-
-        if ( arguments.at(1) == "gst_appsrc" ) {
-            goto end;
-        }
-
-        // If call from terminal and local file or remote file not exists
-        QFile file( arguments.at(1) );
-        if ( ( file.exists() == false ) and
-             ( arguments.at(1).contains( "http://" ) == false ) and
-             ( arguments.at(1).contains( "https://" ) == false ) )
-        {
-            qDebug().noquote() << global::nameOutput << arguments.at(1) << "file not exists";
-            qDebug().resetFormat().noquote() << help;
-            qDebug();
-            return 1;
-        }
-
     }
-    end:
 
-    // Initialize GStreamer
-    // https://developer.gnome.org/gstreamer/stable/gst-running.html
-#ifdef Q_OS_LINUX
+    new QvkLogController;
+
+#ifdef Q_OS_UNIX
     QString separator;
     separator = ":";
 #endif
@@ -118,6 +90,7 @@ int main(int argc, char *argv[])
     // qmake options example:
     // DEFINES+=FOR_MY_LINUX_INSTALLER
 #if defined( Q_OS_WIN ) || defined( FOR_MY_LINUX_INSTALLER )
+
     QvkSettings vkSettings;
     QFileInfo dirPathProfile( vkSettings.getFileName() );
     QString pathProfile = dirPathProfile.absolutePath();
@@ -126,12 +99,16 @@ int main(int argc, char *argv[])
     // Die GStreamer plugins werden über die GST_PLUGIN_PATH_1_0 variable gefunden
     QString pluginPath;
     pluginPath.append( programPath );
+    pluginPath.append( separator );
+    pluginPath.append( programPath + "/gstreamer/gstreamer_lib" );
     qputenv( "GST_PLUGIN_PATH_1_0", pluginPath.toUtf8() );
 
     // Der openh264 Codec wird über die PATH variable gefunden
     QString pathPath;
     pathPath.append( programPath );
     pathPath.append( separator );
+    pathPath.append( programPath + "/gstreamer/gstreamer_bin" );
+    pathPath.append( separator );
     QFileInfo h264Profile( vkSettings.getOpenh264ProfilePathWithFilename() );
     pathPath.append( h264Profile.absolutePath() );
     qputenv( "PATH", pathPath.toUtf8() );
@@ -140,6 +117,20 @@ int main(int argc, char *argv[])
     pathRegistry.append( pathProfile );
     pathRegistry.append( "/gstreamer.registry" );
     qputenv( "GST_REGISTRY_1_0", pathRegistry.toUtf8() );
+
+    // Registry löschen
+    QFile file;
+    file.setFileName( pathRegistry );
+    if ( file.exists() == true ) {
+        qDebug().noquote() << global::nameOutput << "File gstreamer.registry exists";
+        if ( file.remove() == true ) {
+            qDebug().noquote() << global::nameOutput << "File gstreamer.registry removed successfully";
+        } else {
+            qDebug().noquote() << global::nameOutput << "Unable to remove gstreamer.registry file";
+        }
+    } else {
+        qDebug().noquote() << global::nameOutput << "File gstreamer.registry not exists";
+    }
 #endif
 
     // Gstreamer debug begin
@@ -147,14 +138,14 @@ int main(int argc, char *argv[])
     QvkSettings vkSettingsGstDebug;
     QFileInfo fileInfo( vkSettingsGstDebug.getFileName() );
     QString pathAndFilename = fileInfo.absoluteFilePath();
-    // qDebug() << "pathAndFilename:" << pathAndFilename;
+    //qDebug() << "pathAndFilename:" << pathAndFilename;
 
     QString pathToProfile = fileInfo.absolutePath();
-    // qDebug() << "pathProfile" << pathToProfile;
+    //qDebug() << "pathProfile" << pathToProfile;
 
     QSettings setingsGstDebug( pathAndFilename, QSettings::IniFormat );
     QString debugLevel = setingsGstDebug.value( "sliderGstDebugLevel", "0" ).toString();
-    // qDebug() << "debugLevel:" << debugLevel;
+    //qDebug() << "debugLevel:" << debugLevel;
 
     if ( debugLevel.contains( "0" ) == false ) {
         qputenv( "GST_DEBUG", debugLevel.toUtf8() );
@@ -167,14 +158,11 @@ int main(int argc, char *argv[])
 
     gst_init (&argc, &argv);
 
-#ifdef Q_OS_LINUX
-    if ( QvkWaylandRoutines::is_Wayland_Display_Available() == false )
-    {
+#ifdef Q_OS_UNIX
+    if ( QvkWaylandRoutines::is_Wayland_Display_Available() == false ) {
         QvkMainWindow *w = new QvkMainWindow;
         w->show();
-    }
-    else
-    {
+    } else {
         QvkMainWindow_wl *wl = new QvkMainWindow_wl;
         wl->show();
     }
