@@ -76,7 +76,7 @@ QvkRegionChoise::QvkRegionChoise( Ui_formMainWindow *ui_formMainWindow ):handleP
 
 void QvkRegionChoise::slot_init()
 {
-#ifdef Q_OS_LINUX
+#ifdef Q_OS_UNIX
     if ( ui->comboBoxScreencastScreenArea->currentIndex() > -1 ) {
         int index = ui->comboBoxScreencastScreenArea->currentIndex();
         QList<QScreen *> screenList = QGuiApplication::screens();
@@ -90,11 +90,10 @@ void QvkRegionChoise::slot_init()
 #endif
 
 #ifdef Q_OS_WIN
-    // Für das anzeigen der Bereichsanzeige auf dem Bildschirm wird der Index aus einer unsortierten Liste benötigt.
     if ( ui->comboBoxScreencastScreenArea->currentIndex() > -1 ) {
         int index = 0;
         QString nameDisplay = ui->comboBoxScreencastScreenArea->currentText().section( ":", 0, 0 ).trimmed();
-        QList<QScreen *> screenList = QGuiApplication::screens(); // unsortiert
+        QList<QScreen *> screenList = QGuiApplication::screens();
         for ( int i=0; i < screenList.count(); i++ ) {
             QString nameList = screenList.at(i)->name().remove( "." ).remove( "\\" ) ;
             if ( nameDisplay == nameList ) {
@@ -150,12 +149,13 @@ void QvkRegionChoise::paintEvent( QPaintEvent *event )
 {
     (void)event;
     QPixmap pixmap( screenWidth, screenHeight );
+    pixmap.fill( Qt::transparent );
 
     if ( recordemode == false ) {
-        pixmap.fill( Qt::transparent );
         QPainter painterPixmap;
         painterPixmap.begin( &pixmap );
-        painterPixmap.setRenderHints( QPainter::Antialiasing, true );
+        painterPixmap.setRenderHint( QPainter::SmoothPixmapTransform, true );
+        painterPixmap.setRenderHint( QPainter::Antialiasing, true );
         HandleTopLeft( painterPixmap );
         HandleTopMiddle( painterPixmap );
         HandleTopRight( painterPixmap );
@@ -182,10 +182,10 @@ void QvkRegionChoise::paintEvent( QPaintEvent *event )
         }
         painterPixmap.end();
     } else {
-        pixmap.fill( Qt::transparent );
         QPainter painterPixmap;
         painterPixmap.begin( &pixmap );
-        painterPixmap.setRenderHints( QPainter::Antialiasing, true );
+        painterPixmap.setRenderHint( QPainter::SmoothPixmapTransform, true );
+        painterPixmap.setRenderHint( QPainter::Antialiasing, true );
         HandleRecord( painterPixmap,
                       frame_X - radius + penHalf,
                       frame_Y - radius + penHalf,
@@ -240,6 +240,7 @@ void QvkRegionChoise::paintEvent( QPaintEvent *event )
 
     QPainter painter;
     painter.begin( this );
+    painter.setRenderHint( QPainter::SmoothPixmapTransform, true  );
     painter.drawPixmap( QPoint( 0, 0 ), pixmap );
     painter.end();
 
@@ -267,11 +268,11 @@ void QvkRegionChoise::mousePressEvent(QMouseEvent *event)
       case Middle      : { handlePressed = Middle;       handleKeyPressed = Middle;       HandleSelected = Middle;       break; }
     }
 
-    mous_delta_X_to_blueline = event->x() - frame_X;
-    mous_delta_Y_to_blueline = event->y() - frame_Y;
+    mous_delta_X_to_blueline = event->position().x() - frame_X;
+    mous_delta_Y_to_blueline = event->position().y() - frame_Y;
 
-    old_Mouse_X = event->x();
-    old_Mouse_Y = event->y();
+    old_Mouse_X = event->position().x();
+    old_Mouse_Y = event->position().y();
     old_Frame_Width = frame_Width;
     old_Frame_Height = frame_height;
 
@@ -684,10 +685,10 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
     {
       case NoHandle    : break;
       case TopLeft     : { // Move
-                           frame_X = event->x() - mous_delta_X_to_blueline;
-                           frame_Y = event->y() - mous_delta_Y_to_blueline;
-                           frame_Width = old_Mouse_X - event->x() + old_Frame_Width;
-                           frame_height = old_Mouse_Y - event->y() + old_Frame_Height;
+                           frame_X = event->position().x() - mous_delta_X_to_blueline;
+                           frame_Y = event->position().y() - mous_delta_Y_to_blueline;
+                           frame_Width = old_Mouse_X - event->position().x() + old_Frame_Width;
+                           frame_height = old_Mouse_Y - event->position().y() + old_Frame_Height;
 
                            // Limit min
                            if ( frame_Width < frame_min_width ) {
@@ -714,8 +715,8 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
                            break;
                          }
       case TopMiddle   : { // Move
-                           frame_Y = event->y() - mous_delta_Y_to_blueline;
-                           frame_height = old_Mouse_Y - event->y() + old_Frame_Height;
+                           frame_Y = event->position().y() - mous_delta_Y_to_blueline;
+                           frame_height = old_Mouse_Y - event->position().y() + old_Frame_Height;
 
                            // Limit min
                            if ( frame_height < frame_min_height ) {
@@ -732,9 +733,9 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
                            break;
                          }
       case TopRight    : { // Move
-                           frame_Y = event->y() - mous_delta_Y_to_blueline;
-                           frame_Width = event->x() - old_Mouse_X + old_Frame_Width;
-                           frame_height = old_Mouse_Y - event->y() + old_Frame_Height;;
+                           frame_Y = event->position().y() - mous_delta_Y_to_blueline;
+                           frame_Width = event->position().x() - old_Mouse_X + old_Frame_Width;
+                           frame_height = old_Mouse_Y - event->position().y() + old_Frame_Height;;
 
                            // Limit min
                            if ( frame_Width < frame_min_width ) {
@@ -759,7 +760,7 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
                            break;
                          }
       case RightMiddle : { // Move
-                           frame_Width = event->x() - old_Mouse_X + old_Frame_Width;
+                           frame_Width = event->position().x() - old_Mouse_X + old_Frame_Width;
 
                            // Limit min
                            if ( frame_Width < frame_min_width ) {
@@ -774,8 +775,8 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
                            break;
                          }
       case BottomRight : { // Move
-                           frame_Width = event->x() - old_Mouse_X + old_Frame_Width;
-                           frame_height = event->y() - old_Mouse_Y + old_Frame_Height;
+                           frame_Width = event->position().x() - old_Mouse_X + old_Frame_Width;
+                           frame_height = event->position().y() - old_Mouse_Y + old_Frame_Height;
 
                            // Limit min
                            if ( frame_Width < frame_min_width ) {
@@ -798,7 +799,7 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
                            break;
                          }
       case BottomMiddle: { // Move
-                           frame_height = event->y() - old_Mouse_Y + old_Frame_Height;
+                           frame_height = event->position().y() - old_Mouse_Y + old_Frame_Height;
 
                            // Limit min
                            if ( frame_height < frame_min_height ) {
@@ -814,9 +815,9 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
                          }
     case BottomLeft    : {
                            // Move
-                           frame_X = event->x() - mous_delta_X_to_blueline;
-                           frame_height = event->y() - old_Mouse_Y + old_Frame_Height;
-                           frame_Width = old_Mouse_X - event->x() + old_Frame_Width;
+                           frame_X = event->position().x() - mous_delta_X_to_blueline;
+                           frame_height = event->position().y() - old_Mouse_Y + old_Frame_Height;
+                           frame_Width = old_Mouse_X - event->position().x() + old_Frame_Width;
 
                            // Limit min
                            if ( frame_Width < frame_min_width ) {
@@ -841,8 +842,8 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
                            break;
                          }
       case LeftMiddle  : { // Move
-                           frame_X = event->x() - mous_delta_X_to_blueline;
-                           frame_Width = old_Mouse_X - event->x() + old_Frame_Width;
+                           frame_X = event->position().x() - mous_delta_X_to_blueline;
+                           frame_Width = old_Mouse_X - event->position().x() + old_Frame_Width;
 
                            // Limit min
                            if ( frame_Width < frame_min_width ) {
@@ -861,8 +862,8 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
       case Middle      : { // Move
                            int deltaX = ( old_Frame_X2 - framePenHalf - frame_Width/2 ) - old_Mouse_X;
                            int deltaY = ( old_Frame_Y2 - framePenHalf - frame_height/2 ) - old_Mouse_Y;
-                           frame_X = event->x() - frame_Width/2 + framePenHalf + deltaX;
-                           frame_Y = event->y() - frame_height/2 + framePenHalf + deltaY;
+                           frame_X = event->position().x() - frame_Width/2 + framePenHalf + deltaX;
+                           frame_Y = event->position().y() - frame_height/2 + framePenHalf + deltaY;
 
                            // Limit Top
                            if ( frame_Y <= 0 - framePenHalf ) {
@@ -1551,7 +1552,6 @@ qreal QvkRegionChoise::getXRecordArea()
 {
     qreal xReal = ( frame_X + framePenWidth/2 ) * screen->devicePixelRatio();
     int xInt = static_cast<int>( ( frame_X + framePenWidth/2 ) * screen->devicePixelRatio() );
-
     if ( xReal > xInt ) {
         xReal = xInt + 1;
     }
