@@ -25,8 +25,6 @@
 
 #include "ui_formMainWindow.h"
 
-#include "QvkRegionButtonArrow.h"
-
 #include <QWidget>
 #include <QScreen>
 
@@ -56,7 +54,7 @@ public:
   int screenHeight = 400;
 
   bool recordemode = false;
-
+  int zaehler = 0;
 
 public slots:
   void slot_areaReset();
