@@ -34,6 +34,8 @@
 #include <QSettings>
 #include <QDebug>
 #include <QMainWindow>
+#include <QList>
+#include <QColor>
 
 class QvkSettings: public QObject
 { 
@@ -48,8 +50,8 @@ public:
     void saveAreaScreencast( qreal x, qreal y, qreal width, qreal height );
     void readAreaScreencast( QvkRegionChoise *vkRegionChoise );
 
-    void saveCamera( int x, int y );
-    void readCamera( QvkCameraController *vkCameraController );
+    void saveCamera( int index, int x, int y );
+    void readCamera(QList<QvkCameraSingle *> cameraSingleList);
 
     void saveSystrayAlternative( int x, int y );
     void readSystrayAlternative( QvkSystrayAlternative *vkSystrayAlternative );
