@@ -4,6 +4,7 @@
 
 #include <QWidget>
 #include <QPainter>
+#include <QColor>
 
 class QvkSpezialCheckbox : public QWidget
 {
@@ -12,8 +13,13 @@ class QvkSpezialCheckbox : public QWidget
 public:
     QvkSpezialCheckbox(QWidget *parent = 0);
     bool isChecked();
+    void set_colorChecked( QColor color );
+    void set_colorUnChecked ( QColor color );
+    void set_imageChecked( QString value );
+    void set_imageUnChecked( QString value );
+    void set_waitBeforeTrigger( int value );
+
 
-    
 public slots:
     void slot_setChecked( bool value );
     void slot_click();
@@ -40,6 +46,14 @@ private:
     void paintChecked( QPainter &painter );
     void paintUnChecked( QPainter &painter );
 
+    QColor colorChecked;
+    QColor colorUnChecked;
+
+    QString imageChecked;
+    QString imageUnChecked;
+
+    int waitBeforeTrigger = 0;
+
 
 signals:
     void signal_clicked( bool );
