@@ -9,16 +9,9 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
-<context>
-    <name>QvkCameraSettingsDialog</name>
-    <message>
-        <source>Camera settings</source>
+        <source>Select one or more devices</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -59,14 +52,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation type="unfinished"></translation>
@@ -94,13 +79,6 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>QvkDirectSoundController</name>
-    <message>
-        <source>Select one or more devices</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>QvkHelp</name>
     <message>
@@ -119,6 +97,17 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -192,6 +181,14 @@
         <source>Donate</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QvkPulseAudioWatcher</name>
@@ -200,6 +197,13 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -487,18 +491,6 @@
         <source>Gray</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation type="unfinished"></translation>
@@ -507,10 +499,6 @@
         <source>Open folder</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation type="unfinished"></translation>
@@ -698,18 +686,6 @@
         <source>Stop</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Pause</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Continue</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Folder</source>
         <translation type="unfinished"></translation>
@@ -718,6 +694,66 @@
         <source>Do not record mouse cursor</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Second wait before recording</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>license</name>
