@@ -25,6 +25,8 @@
 
 #include <wayland-client.h>
 #include <QDebug>
+#include <QString>
+#include <QTime>
 
 QvkWaylandRoutines::QvkWaylandRoutines( QWidget *parent )
 {
